
# Midjourney Docs

## Chapter 1: Web Quick Start

Web Quick Start

Check out this video for a quick introduction to midjourney.com, then follow the guide below to create your first images!

### Making Images on midjourney.com

1\. Make Images from the Imagine Bar

At the top of most pages on the website, you'll see the imagine bar. To start making images, type a prompt into the bar and hit enter.

Once your images start generating, you can find them on the Create tab. Click over to see your results.

2\. Make Variations

From the Create tab, you can see all the images you've made. Click on an image to open the lightbox. Once you have an image you like, you can make new versions with variations.

The lightbox also shows additional tools to help you refine and experiment with your images. Learn more about other buttons in the lightbox on their feature pages: Upscale, Reframe, Repaint.

3\. Change Your Settings

The  button in the imagine bar lets you set default parameters for all your prompts. You can adjust the aspect ratio, stylization, and variety of your images, or adjust your generation speed and stealth.

4\. Use Images in Your Prompts

Midjourney can use existing images as inspiration for brand new ones. If you see an image you like on the Explore page, or want to use an image you generated as a style reference for a totally new prompt, drag and drop that image to the imagine bar.

There are three different ways you can use images:

For a deep dive into using reference images, check out our Working with Images on Web page.

5\. Save and Manage Images

If you're ready to download your images, or want to filter or organize them, visit the Archive tab.

Wherever you see the  button, you can click to save an individual image. You can also download your images in bulk by clicking outside the grid and dragging to make a selection.

You can find more information about the filters and other options on the Archive here.

6\. Create Collaboratively with Chat

Nothing beats the creative energy that comes from making images with others! On the  Chat tab, you can find (or create!) shared spaces to work together with other users.

Need some inspiration? Check out the Daily Theme chat every day to pick up a new theme for your prompts! Hang out there to see the creative ways other users are incorporating the day's theme, or create alongside them.

### Need Help?

You can learn more about all of Midjourney's features and how to use them right here in our documentation. Some popular features:

Setting a non-square aspect ratio

Using an image as an image, style, or character reference

Using the describe feature with an image you like will suggest words and phrases you can use in your prompts to generate similar images

You can ask questions any time in the Help Room.

If you need help with your account, you can browse helpful billing FAQs or submit a ticket to our billing team by visiting help.midjourney.com.



ARTICLE: 

### Making Images on midjourney.com

1\. Make Images from the Imagine Bar

2\. Make Variations

3\. Change Your Settings

4\. Use Images in Your Prompts

5\. Save and Manage Images

6\. Create Collaboratively with Chat

Need Help?

### Discord Quick Start

Discord Quick Start

Use the Midjourney bot to generate stunning images from simple text prompts in seconds. Work directly in Discord. No specialized hardware or software is required.

Code of Conduct

Don't be a jerk.

Don't use our tools to make images that could inflame, upset, or cause drama. That includes gore and adult content.

Be respectful to other people and the team.

### Making Images with Midjourney

1\. Log In To Discord

Access the Midjourney Bot through Discord via web browser, mobile app, or desktop app. Ensure you have a verified Discord account before joining the Midjourney Discord server.

Follow these guides to create or verify your Discord account:  
Create Discord Account  
Verify Discord Account

2\. Subscribe to a Midjourney Plan

To start generating images with Midjourney, you'll need to subscribe to a plan.

Visit Midjourney.com.

Log in using your verified Discord account.

Choose a subscription plan that suits your needs.

Go to Subscription Plans for information on pricing and the features available with each tier.

3\. ‚ÄâJoin the Midjourney Server on Discord

To start interacting with the Midjourney Bot, join the Midjourney Server

Open Discord and locate the server list on the left-hand sidebar.

Press the `+` button at the bottom of the server list.

In the pop-up window, click the `Join a Server` button.

Paste or type the following URL: http://discord.gg/midjourney and press `Join`.

For additional information, Learn more about Discord servers.

4\. Go to any #General or #Newbie Channel

After joining the Midjourney server on Discord, you'll see several channels listed in the sidebar.

On the Midjourney Server

Locate and select any channel labeled `general-#` or `newbie-#`. These channels are designed for beginners to start using the Midjourney Bot. The Midjourney Bot will not generate images in other channels.

On Other Servers

You can generate images with the Midjourney Bot on any Discord server that has invited the Midjourney Bot. Look for instructions on your server on where to use the Bot.

5.‚ÄâUse the /imagine Command

About Discord Commands  
Interact with the Midjourney Bot on Discord using a Command. Commands are used to create images, change default settings, monitor user info, and perform other helpful tasks. The `/imagine` command generates a unique image from a short text description (known as a Prompt). Learn more about Prompts

How to Use `/imagine`

Type '/imagine prompt:' in the message field. You can also select the `/imagine` command from the list of available slash commands that pop up when you type '/'.

Type a description of the image you want to create in the `prompt` field.

Send your message. The Bot will interpret your text prompt and begin generating the images.

Respect the Community Guidelines. Community guidelines apply wherever the Midjourney Bot is used.

6.‚ÄâAccept the Terms Of Service

Before generating any images, the Midjourney Bot will prompt you to accept the Terms Of Service. You must agree to these terms to proceed with image creation.

7.‚ÄâImage Generation Process

After submitting a text prompt, the Midjourney Bot processes your request, creating four unique image options within a minute. This process utilizes advanced Graphics Processing Units (GPUs), and each image generation counts towards the GPU time included with your Midjourney subscription. To monitor your available GPU time (Fast Time Remaining) use the `/info` command.

8.‚ÄâSelect an Image or Create Variations

Once your initial image grid has been generated, two rows of buttons become available underneath your image grid.

`U1` `U2` `U3` `U4` Image Selection

In earlier versions of Midjourney, the `U` buttons were used for upscaling images. With the latest model, images are immediately generated at 1024 x 1024 pixels size. Now, the 'U' buttons help you separate out your chosen image from the grid, making it easier to download and giving you access to additional editing and generation tools.

`üîÑ` Re-run or Re-roll a Job

The `üîÑ` button re-runs a Job. In this case, it would re-run the original prompt producing a new grid of images.

`V1` `V2` `V3` `V4` Image Variation

The `V` buttons are used to create variations of the selected image. Each button generates a new image grid that maintains the general style and composition of the selected image.

9.‚ÄâEnhance or Modify Your Image

After singling out an image, an expanded set of options becomes available.

`ü™Ñ Vary (Strong)` `ü™Ñ Vary (Subtle)`

Create a stronger or subtle variation of your selected image, generating a new grid of four options.

`üîç Zoom Out 2x` `üîç Zoom Out 1.5x` `üîç Custom Zoom`

Zoom Out of your image, extending the canvas its original boundaries without changing the content of the original image. The newly expanded canvas will be filled-in using guidance from the prompt and the original image.

`‚¨ÖÔ∏è` `‚û°Ô∏è` `‚¨ÜÔ∏è` `‚¨áÔ∏è`

The Pan buttons allow you to expand the canvas of an image in a chosen direction without changing the content of the original image. The newly expanded canvas will be filled in using guidance from the prompt and the original image.

`‚ù§Ô∏è Favorite`

tag your best images to easily find them on the Midjourney website.

`Web ‚ÜóÔ∏è`

Open the image in your gallery on midjourney.com

10.‚ÄâSave Your Image

Click on the image to open it to full size, and then right-click and choose `Save image`. On mobile, long-tap the image and then tap the download icon in the top right corner.

All images are immediately available to view on midjourney.com/imagine

### Next Steps

Direct Messaging the Midjourney Bot  
Are you having difficulty finding yourself while working with other users on the Midjourney server? You can interact with the Midjourney Bot one-on-one in a direct message. Images created within your direct messages are still subject to content and moderation rules and are visible on the Midjourney website.

Learn More About Prompts  
Learn how to write effective and creative prompts, 
Explore how descriptions of artistic mediums, locations, and time periods change an image.

Blend Your Own Images  
Learn how to upload and blend your own images using the `/blend` command.

### Midjourney Bot Assistance

Need help or have questions? Try these commands:  
`/help` Displays useful information and tips about the Midjourney Bot.  
`/ask` Provides answers to questions about the Midjourney Bot.

You can also visit the #support channel on the Midjourney Discord for additional assistance.

### Billing and Subscription Queries

For billing and subscription questions, please visit help.midjourney.com.

You can interact with the Midjourney Bot on Discord by typing a¬†Command. Commands are used to create images, change default settings, monitor user info, and perform other helpful tasks.

Midjourney Commands can be used in any Bot Channel, on private Discord servers where the Midjourney Bot has been permitted to operate, or in a direct message with the Midjourney Bot.

A Prompt is a short text phrase that the Midjourney Bot interprets to produce an image. The Midjourney Bot breaks down the words and phrases in a prompt into smaller pieces, called tokens, that can be compared to its training data and then used to generate an image. A well-crafted prompt can help make unique and exciting images.



------

## Chapter 2: Making Images with Midjourney

1\. Log In To Discord

2\. Subscribe to a Midjourney Plan

3\. ‚ÄâJoin the Midjourney Server on Discord

4\. Go to any #General or #Newbie Channel

On the Midjourney Server

On Other Servers

5.‚ÄâUse the /imagine Command

6.‚ÄâAccept the Terms Of Service

7.‚ÄâImage Generation Process

8.‚ÄâSelect an Image or Create Variations

9.‚ÄâEnhance or Modify Your Image

10.‚ÄâSave Your Image

Next Steps

Midjourney Bot Assistance

Billing and Subscription Queries

### Community Guidelines

Community Guidelines

TL; DR

Midjourney is an open-by-default community. To keep the platform accessible and welcoming to the broadest number of users, content must be `Safe For Work` (SFW).

We have 4 main rules

Be kind and respect each other

SFW content only

Be thoughtful about how you share your creations

Unauthorized automation & third party apps are not allowed

Thank you for helping us make Midjourney a safe, welcoming space for everyone.

If you see someone violating these guidelines, you can report it here.

Please use these incredible powers with joy, wonder, responsibility and respect.

### Rules

Be kind and respect each other

Be kind and respect each other and staff. Violent behavior, harassment or incitement of any kind will not be tolerated.

Do not create images or use text prompts that are inherently disrespectful, aggressive, or otherwise abusive.

Do not create or use imagery of real people, famous or otherwise, that could be used to harass, abuse, defame, or otherwise harm.

Respect others’ rights. Do not attempt to find out others' private information. Do not upload others’ private information.

SFW content only

Do not create or attempt to create gore or adult content. Avoid making visually shocking or disturbing content.

What is Considered Gore? Gore includes images of detached body parts of humans or animals, cannibalism, blood, violence (images of shooting or bombing someone, for instance), mutilated bodies, severed limbs, pestilence, etc.

What is NSFW or Adult Content? Avoid nudity, sexual organs, fixation on such things, sexualized imagery, fetishes, people in showers, on toilets, etc.

Do not create or attempt to create content that in any way sexualizes children or minors. This includes real images as well as generated images. Do not generate, upload, share, or make attempts to distribute content that depicts, promotes, or attempts to normalize child sexual abuse.

Do not create other offensive content. Other things may be deemed offensive or abusive because they can be viewed as racist, homophobic, disturbing, or in some way derogatory to a community. This includes offensive or inflammatory images of celebrities or public figures.

Be thoughtful about how you share your creations

Do not publicly repost the creations of others without their permission.

Be careful about sharing. It’s okay to share your creations outside of the Midjourney community, but please consider how others might view your content.

Do not generate images to spread misinformation or disinformation.

Do not generate images for political campaigns or to try to influence the outcome of an election.

Do not generate images to attempt to or to actually deceive or defraud anyone.

Do not intentionally mislead recipients of generated images about their nature or source.

Unauthorized automation and third party apps are not allowed

In order to maintain the highest quality experience for all users, Midjourney accounts are designed for individual use and each user may maintain only one account.

With a few rare exceptions that are explicitly granted, Midjourney does not provide an API, nor provide third-party apps or scripts, and automating interactions with Midjourney service is strictly prohibited according to our Terms of Service. Accounts who do not comply with these rules may be blocked.

You may not resell or redistribute Midjourney Services or access to the Service (this includes sharing your account).

Moderation Policy Notes

Midjourney will block some text and image inputs automatically. An input not being automatically blocked does not necessarily mean that it is allowed.

Users who violate the Terms of Service may be warned by a community moderator, given a time-out, or be blocked from the service.

If you see someone else’s content that breaks the rules, please report it.

Overall Policy Notes

The above rules apply to all content, including images made in private servers, images deleted/hidden, using Stealth Mode, in direct messages with the Midjourney Bot, and Midjourney websites.

Any violations of these rules may lead to bans from our services.

Midjourney is both a product and community. We may revoke your access to the community separately from access to the product.

Content guidelines are continually reviewed and may be modified as the Midjourney community grows.

Do not generate images for illegal activity or upload images to our servers that involve illegal activity, or where the uploading itself may be illegal.

This is not an exhaustive list. We may take action against users that violate the spirit of these guidelines, even if their actions are not explicitly prohibited.

We are a small team striving to balance the needs of the broadest number of users in our community. Our decision making process is not a democracy, but we take feedback on moderation very seriously.

Most importantly, have fun!

### Specific Community Guidelines & Important Reminders for External Image Editor

The editor is a powerful new tool for unleashing imagination. It’s not for creating images that might deceive, harass, or maliciously harm others.

Do not abuse the editor to manipulate images of real people, famous or otherwise, in ways that could lead to harassment, abuse, or harm.

Do not abuse the editor to create images intended to offend, deceive, or maliciously harm others.

Do not abuse the editor to create NSFW or sexualized imagery. We will take especially strict action against anyone attempting to produce sexualized images of real people.

Anyone attempting to violate our Community Guidelines using the editor will face suspension or banning without refund.  
Use this tool with respect and consideration for others.

### Self-Policing and Reporting

Occasionally prompts will unintentionally produce not safe for work content. Please self-police these images by using the ❌ emoji reaction or by right-clicking selecting Apps and then clicking `Cancel Job` to delete the image.

Users may flag any image for moderator review by right-clicking selecting Apps, and then clicking `Report Job` within Discord or the website by selecting `...` under an image and clicking `Report`.

Report Images in Discord

Report Images on the Website

### 



------

## Chapter 3: Rules

Specific Community Guidelines & Important Reminders for External Image Editor

Self-Policing and Reporting

### Prompts

Prompts

A prompt is a short text phrase that the Midjourney Bot interprets to produce an image. The Midjourney Bot breaks down the words and phrases in a prompt into smaller pieces, called tokens, that are compared to its training data and then used to generate an image. A well-crafted prompt can help make unique and exciting images.

Basic Prompts

A basic prompt can be as simple as a single word, phrase or emoji üòä.

Prompting Tip!

The Midjourney Bot works best with simple, short phrases that describe what you want to see. Avoid long lists of requests and instructions. Instead of: Show me a picture of lots of blooming California poppies, make them bright, vibrant orange, and draw them in an illustrated style with colored pencils Try: Bright orange California poppies drawn with colored pencils

### Advanced Prompts

More advanced prompts can include one or more image URLs, multiple text phrases, and one or more parameters

`Image Prompts`

Image URLs can be added to a prompt to influence the style and content of the finished result. Image URLs always go at the front of a prompt.

Read more about Image Prompts

`Text Prompt`

The text description of what image you want to generate. See below for prompting information and tips. Well-written prompts help generate amazing images.

`Parameters`

Parameters change how an image generates. Parameters can change aspect ratios, models, upscalers, and lots more. Parameters go at the end of the prompt.

Read more about Parameters

### Prompting Notes

Word Choice

Word choice matters. More specific synonyms work better in many circumstances. Instead of big, try huge, gigantic, enormous, or immense.

Plural words and Collective Nouns

Plural words leave a lot to chance. Try specific numbers. "Three cats" is more specific than "cats." Collective nouns also work, ‚Äúflock of birds‚Äù instead of "birds.‚Äù

Focus on What You Want

It is better to describe what you want instead of what you don‚Äôt want. If you ask for a party with ‚Äúno cake, ‚Äù your image will probably include a cake. To ensure an object is not in the final image, try advanced prompting using the `--no` parameter.

Prompt Length and Details

Prompts can be simple. A single word or emoji will work. However, short prompts rely on Midjourney‚Äôs default style, allowing it to fill in any unspecified details creatively. Include any element that is important to you in your prompt. Fewer details means more variety but less control.

Try to be clear about any context or details that are important to you. Think about:

Subject: person, animal, character, location, object

Medium: photo, painting, illustration, sculpture, doodle, tapestry

Environment: indoors, outdoors, on the moon, underwater, in the city

Lighting: soft, ambient, overcast, neon, studio lights

Color: vibrant, muted, bright, monochromatic, colorful, black and white, pastel

Mood: sedate, calm, raucous, energetic

Composition: portrait, headshot, closeup, birds-eye view



------

## Chapter 4: Basic Prompts

Advanced Prompts

Prompting Notes

Word Choice

Plural words and Collective Nouns

Focus on What You Want

Prompt Length and Details

### Explore Prompting

Explore Prompting

Even short single-word prompts will produce beautiful images in Midjourney's default style, but you can create more interesting personalized results by combining concepts like artistic medium, historical periods, location, and more.

### Pick A Medium

Break out the paint, crayons, scratchboard, printing presses, glitter, ink, and colored paper. One of the best ways to generate a stylish image is by specifying an artistic medium.

prompt example: `/imagine prompt` `<any art style> style cat`

Block Print

Ballpoint Pen Sketch

Cyanotype

Graffiti

Paint-by-Numbers

Risograph

Ukiyo-e

Pencil Sketch

Watercolor

Pixel Art

Blacklight Painting

Cross Stitch

Acrylic Pour

Cut Paper

Pressed Flower

### Get Specific

More precise words and phrases will help create an image with exactly the right look and feel.

prompt example: `/imagine prompt` `<style> sketch of a cat`

Life Drawing

Continuous Line

Loose Gestural

Value Study

Charcoal

### Time Travel

Different eras have distinct visual styles.

prompt example: `/imagine prompt` `an illustration of a <time period> cat`

1400s

1500s

1600s

1700s

1800s

1900s

1910s

1920s

1930s

1940s

1950s

1960s

1970s

1980s

1990s

### Emote

Use emotion words to give characters personality.

prompt example: `/imagine prompt` `<emotion> cat`

Determined

Happy

Sleepy

Angry

Shy

### Get Colorful

A full spectrum of possibilities.

prompt example: `/imagine prompt` `<color word> colored cat`

Millennial Pink

Acid Green

Desaturated

Canary Yellow

Peach

Two Toned

Pastel

Mauve

Ebony

Neutral

CMYK

Blue Tinted

Iridescent

Brightly

Pink and Blue

### Environmental Exploration

Different environments can set unique moods.

prompt example: `/imagine prompt` `<location> cat`

Tundra

Salt Flat

Jungle

Desert

Forest

Cave

Farm

Crystal Forest

City

Garden



------

## Chapter 5: Pick A Medium

Get Specific

Time Travel

Emote

Get Colorful

Environmental Exploration

### Variations

Variations

Use the `V1` `V2` `V3` `V4` buttons under each image grid, or use the `Vary (Strong)` and `Vary (Subtle)` buttons under an upscaled image to generate different versions of that image.

The `V` buttons correspond to the images in each generated grid from left to right, top to bottom, like this: ðŸ`¢.

Control your default amount of variation when using the `V` buttons with the `ðŸŽ¨ High Variation Mode` and `ðŸŽ¨ Low Variation Mode` in your settings. `ðŸŽ¨ High Variation Mode` is the default.

You can also use the `/prefer variability` command to toggle between High and Low Variation Modes.

Under upscaled images, the `ðŸª„ Vary (Strong)` button corresponds to `ðŸŽ¨ High Variation Mode`, while `ðŸª„ Vary (Subtle)` corresponds to `ðŸŽ¨ Low Variation Mode`. These buttons ignore your personal settings.

Want to change your prompt while you make variations? Enable `Remix Mode` in your settings. Learn more about using Remix Mode and how it interacts with your variation settings here.

### Variation Examples

When using Midjourney Version 5 or 6, or Niji Version 5 or 6, you can choose between High and Low variation modes.

The default `ðŸŽ¨ High Variation Mode` will produce new images that vary from the original image in composition, number of elements, colors, and types of details. To use High Variation Mode, click a `V` button beneath a grid while you have it selected in settings, or click the `ðŸª„ Vary (Strong)` button beneath an upscaled image.

`ðŸŽ¨ Low Variation Mode` will produce new images that retain the composition and colors of the original, but with subtle changes to the image details. To use Low Variation Mode, select it in `/settings` and click the `V` button corresponding to the iamge you want to vary, or click the `ðŸª„ Vary (Subtle)` button beneath an upscaled image.

Prompt example: `/imagine prompt` `a cute robot holding flowers`

Original Upscaled Image

Image grid using `ðŸª„Vary (Subtle)`

Image grid using `ðŸª„Vary (Strong)`

Prompt example: `/imagine prompt` `a bird watching a butterfly`

Original Upscaled Image

Image grid using `ðŸª„Vary (Subtle)`

Image grid using `ðŸª„Vary (Strong)`



------

## Chapter 6: Upscalers

Upscalers

The current Midjourney and Niji Model Versions produce grids of 1024 x 1024 pixel images. Use the `U1` `U2` `U3` `U4` buttons under each image grid to separate your selected image from its grid. You can then use the `Upscale (Creative)` or `Upscale (Subtle)` tools to increase the size of your image.

The `Upscale (Subtle)` option doubles the size of your image and keeps details very similar to the original. `Upscale (Creative)` also doubles the size of your image but adds new details to the image. Experiment with each upscaler option to find the one most suitable for the style of your image.

`Upscale` tools use your subscription's GPU minutes. Upscaling can take up to twice as many GPU minutes as generating an initial image grid.

`Upscale` tools in Midjourney Version 5.x and 6.0 are not compatible with the --tile parameter.

### How to Use the Upscale Tools

1\. Generate an Image

Create an image using the `/imagine` command.

2\. Select an Image

Use a `U` button to separate your selected image from the grid.

3\. Select Upscale 

Click on the `Upscale (Subtle)` or `Upscale (Creative)` button to upscale your image. The upscalers will double the size of your image to 2048 x 2048 pixels.

Upscale Comparison

Prompt: `chiaroscuro rooster portrait`  
Original 1024 by 1024 pixel image.

Detail from original image

Original image

After upscaling to 2048 x 2048 px

Upscale Comparison

Prompt: `1960s pop-art acrylic painting of a stream running through a redwood forest`

Original image

Subtle upscale

Creative upscale

Detail from original image

Detail from subtle upscale

Detail from creative upscale

Upscale Tip

Upscale jobs you generated before new upscalers were released by refreshing them with the /show command. Buttons for all upscalers compatible with that image will appear under the refreshed job.

### Legacy Upscalers

Earlier Midjourney model versions generated grids of lower-resolution images. You can use a legacy Midjourney upscaler on these images to increase the size and add additional details. There are multiple legacy upscale models available for upscaling images made with earlier Midjourney models. Using a legacy upscaler uses your subscription's GPU minutes.

The Midjourney Bot processes jobs on high-end GPUs. Each minute that it takes to complete a job is a GPU minute. You have a limited amount of GPU minutes when in Fast Mode. Because image generations may be processed on multiple GPUs simultaneously, GPU minutes are not directly connected to the time you wait for an image to generate.

The Midjourney Bot processes jobs on high-end GPUs. Each minute that it takes to complete a job is a GPU minute. You have a limited amount of GPU minutes when in Fast Mode. Because image generations may be processed on multiple GPUs simultaneously, GPU minutes are not directly connected to the time you wait for an image to generate.



------

## Chapter 7: How to Use the Upscale Tools

1\. Generate an Image

2\. Select an Image

3\. Select Upscale 

Upscale Comparison

Detail from original image

Upscale Comparison

Legacy Upscalers

### Vary Region

Vary Region

Use the Midjourney Vary Region editor to select and regenerate specific parts of an upscaled image.

The `Vary (Region)` button appears after a Midjourney image has been upscaled.

Regional variations are guided by the content in your original image and the area you select.

`Vary (Region)` is compatible with Midjourney Model Versions `V5`, `V6`, `niji 5`, and `niji 6`.

### How to Use Vary Region

1\. Generate an Image

Create an image using the `/imagine` command.

2\. Upscale the Image 

Use the U buttons to upscale your selected image.

3\. Select Vary Region 

Click on the `üñåÔ∏è Vary (Region)` button to open the editing interface.

4\. Select Areas to Regenerate

Choose the freehand or rectangular selection tools in the lower left of the Editor.

Select the areas of your image that you want to regenerate.

The size of your selection will affect your results. Larger selections give the Midjourney Bot more room to generate new creative details. Smaller selections will result in smaller, more subtle changes.  
Note: You cannot edit an existing selection but can undo multiple steps using the undo button in the upper right corner.

5\. Submit Your Job

Click the `Submit ‚Üí` button to send your request to Midjourney Bot. The Vary Region editor can now be closed, and you can return to Discord while your Job is processed.

Note You can use the `üñåÔ∏è Vary (Region)` button underneath an upscaled image multiple times to experiment with different selections. Your previous selection will be preserved. You can continue to add to this existing selection or use the `undo` button to clear your selection.

6\. View Your Results

The Midjourney Bot will process your Job and generate a new image grid of variations within the area you selected.

### Vary Region Examples

Upscaled Image

Prompt: colorful candy brooches

Selection

Result

Upscaled Image

Prompt: architectural drawing of a house

Selection

Result

### Vary Region + Remix Mode

You can use Remix mode with the Vary Region editor to update your prompt while regenerating specific parts of your image. Read about using Remix Mode with the Vary Region editor.

Original Image

Prompt: `gouache alligator in sunglasses`

Selection

Updated Prompt: `gouache alligator in green sunglasses`

Result

Updated Prompt: `gouache alligator in green sunglasses`

### Technical Details

Jobs generated using Vary (Region) will honor the following parameters:  
--chaos  
--fast  
--iw  
--no  
--stylize  
--relax  
--style  
--version  
--video  
--weird



------

## Chapter 8: How to Use Vary Region

1\. Generate an Image

2\. Upscale the Image 

3\. Select Vary Region 

4\. Select Areas to Regenerate

5\. Submit Your Job

6\. View Your Results

Vary Region Examples

Vary Region + Remix Mode

Technical Details

### Vary Region + Remix

Vary Region + Remix

Combine Remix Mode and the Midjourney Vary Region editor to select and regenerate specific parts of an upscaled image using a new or modified prompt.

The `Vary (Region)` button appears after a Midjourney image has been upscaled.

Regional variations results are guided by the content in your original image, the area you select, and the modified prompt used.

`Vary (Region)` is compatible with Midjourney Model Versions `V5`, `V6`, `niji 5`, and `niji 6`.

### How to Use Remix Mode with Vary (Region)

1\. Enable Remix Mode

Use the `/settings` command and select `üéõÔ∏è Remix` from the pop-up.

2\. Generate an Image

Create an image using the `/imagine` command.

3\. Upscale the Image 

Use the U buttons to upscale your selected image.

4\. Select Vary Region 

Click the `üñåÔ∏è Vary (Region)` button to open the editing interface.

5\. Select Areas to Regenerate

Choose the freehand or rectangular selection tools in the lower left of the Editor.

Select the areas of your image that you want to regenerate.

The size of your selection will affect your results. Larger selections give the Midjourney Bot more room to generate new creative details. Smaller selections will result in smaller, more subtle changes.  
Note: You cannot edit an existing selection but can undo multiple steps using the undo button in the upper right corner.

6\. Modify Your Prompt

Describe what you want to generate in the selected areas with an updated prompt. Your revised prompt should focus on the details you want to introduce or change.

7\. Submit Your Job

Click the `Submit ‚Üí` button to send your request to Midjourney Bot. The Vary Region editor can now be closed, and you can return to Discord while your Job is processed.

Note You can use the Editor Button underneath an upscaled image multiple times to experiment with different selections and prompts.

8\. View Your Results

The Midjourney Bot will process your Job and generate a new image grid using the information from your original image and the guidance of your new prompt.

New Image Grid

Original vs. Varied Comparison

8\. Upscale and Vary Region again

You can upscale one of your new images and use the Vary Region Editor again to continue refining your image.

Selection

Result

Updated Prompt: hot air balloon lithograph

Result

Updated Prompt: castle in the meadow lithograph

### Vary Region + Remix Prompting Tips

Selections The size of your selection affects the outcome. Larger selections provide the Midjourney Bot with more contextual information, which can improve the scaling and context of new additions. But selecting too much may lead to the newly generated elements blending or replacing parts of the original image you wished to preserve.

Prompts Experiment with how you modify your prompt when Using Vary Region + Remix Mode. Prompts should focus on what you want to happen in the selected area. The Midjourney Bot also considers the existing image when generating a selected area, so shorter focused prompts often are more effective. Midjourney Prompts should not be conversational. Instead of "Please change the meadow trail into a beautiful stream, " be direct and prompt "meadow stream."

Work in Small Steps If you want to change many parts of an image, work on one part at a time. This way, you can create a focused prompt for each part.  
  

### Vary Region + Remix Examples

Original Image

Prompt: `gouache alligator in sunglasses`

Selection

Updated Prompt: `gouache alligator in green sunglasses`

Result

Updated Prompt: `gouache alligator in green sunglasses`

Original Image

Prompt: `scratchboard apple tree branch`

Selection

Updated Prompt: `rainbow scratchboard apple tree branch`

Result

Updated Prompt: `rainbow scratchboard apple tree branch`

### Technical Details

Jobs generated using Vary (Region) + Remix Mode will honor the following parameters:  
--chaos  
--fast  
--iw  
--no  
--stylize  
--relax  
--style  
--version  
--video  
--weird



------

## Chapter 9: Discord Interface

Discord Interface

You can interact with the Midjourney Bot on Discord. The Midjourney server has channels for working collaboratively, technical and billing support, official announcements, offering feedback, and discussions. The community is supportive, encouraging, and eager to share their knowledge with users just starting out.

Midjourney Discord: `https://discord.gg/midjourney`

### Discord Interface

Server List

Direct Messages  
Work one-on-one with the Midjourney Bot in your Direct Messages for a quieter experience.

Midjourney Official Server  
The official Midjourney server with channels for collaboration and billing/technical support.

Channel List

# support  

Visit this channel for billing and technical support from Midjourney Guides.

# newbies  

Visit any #newbies channel to create images.

Member List

Midjourney Bot  
The bot that produces images with the `/imagine` command

Moderators and Guides  
Moderators and Guides can help with billing and technical problems in the support channels.

### Image Grids

The `/imagine` command produces a grid of low-resolution image options based on your prompt. Use the buttons under each image grid to create variations of an image, upscale an image, or rerun the last Midjourney Bot action.

Upscale Buttons

`U1` `U2` `U3` `U4` buttons separate an image from the image grid, allowing you easily download that image or use additional tools like Zoom Out, or Pan.

When using legacy Midjourney model versions the U buttons would upscale an image generating a larger version of the selected image and adding more details, which uses Fast GPU time.

Redo

` üîÑ` The redo (re-roll) button reruns a job. In this case, it would rerun the original prompt producing a new grid of images.

Variation Buttons

`V1` `V2` `V3` `V4` V buttons create incremental variations of the selected grid image. Creating a variation generates a new image grid similar to the chosen image's overall style and composition.

### Upscaled Images

`ü™Ñ Make Variations` `Web ‚ÜóÔ∏è` `‚ù§Ô∏è Favorite`

Make Variations: creates a variation of the upscaled image and generates a new grid of four options.

Web: Open the image in your gallery on midjourney.com

Favorite: tag your best images to easily find them on the Midjourney website.

### Direct Messages

If the #general or #newbie channels are moving too fast, Midjouney subscribers can work one-on-one with the Midjourney Bot in their Discord direct messages.  
Learn how to direct message the Midjourney Bot

### Emoji Reactions

React with different emojis to Midjourney Jobs to send images to your Direct Messages, cancel a job in progress, or delete an image.  
Learn how to use emoji reactions.

### Daily Theme Channel

Participate in a fun themed group image generation in the #daily-theme channel. Look for the day's theme next to the channel's name. All generations must include day's keyword(s).

Turn off the daily theme notification

Want to avoid the daily notification from the daily theme channel? Use the `/daily_theme` command to turn off notifications for that channel.



------

## Chapter 10: Midjourney Discord: https://discord.gg/midjourney

Discord Interface

Server List

Channel List

Member List

Image Grids

Upscale Buttons

Redo

Variation Buttons

Upscaled Images

Direct Messages

Emoji Reactions

Daily Theme Channel

### Direct Messages

Direct Messages

Midjourney subscribers can work one-on-one with the Midjourney Bot in their Discord Direct Messages.

Images generated in your direct messages are still subject to content and moderation rules. They will be visible to other users on the Midjourney website unless you're generating them in Stealth Mode.

### How to Message the Bot

Click on the Midjourney Bot from the Member List (or anywhere you see the Midjourney Bot's name)

Send any message to the Midjourney Bot.

This will begin your Direct Message conversation with the Midjourney Bot.

Find Your Direct Messages

If you accidentally closed or archived your direct message with the Midjourney Bot, send the bot another message to recover it.

Discord Mobile

Discord Desktop

### Troubleshooting

If you donâ€™t see messages from the Bot, adjust your privacy settings:

Discord Desktop

Right-click the Midjourney server icon

Select More Options

Toggle "Allow direct messages from server members." on

Discord Mobile

Long-press the Midjourney server icon

Select Privacy Settings

Scroll down to the "Allow direct messages from server members" toggle.

The Member List appears on the right side of the screen on the desktop version of Discord. If you don't see it, click the "Show Member List" icon next to the Discord search bar:

On mobile, while looking at any channel in the Midjourney server, tap the channel name to see a list of members.



------

## Chapter 11: How to Message the Bot

Find Your Direct Messages

Discord Mobile

Discord Desktop

Troubleshooting

Discord Desktop

Discord Mobile

### Discord Emoji Reactions

Discord Emoji Reactions

React with different emojis to Midjourney jobs to send images to your Direct Messages, cancel a job in progress, or delete an image.

React to a generation with an emoji to trigger actions from the Midjourney Bot.

### ❌ Cancel and Delete

❌ Cancels or deletes a job at any time. Reacting to a job with an X emoji also removes the job from the Midjourney website. If you want to delete an image from the Midjourney webpage but can't find the image within Discord, use the `/show` command  to revive the job. The ❌ reaction only works with your own jobs.

✉️ Send to Direct Messages

React with the envelope emoji ✉️ to send a completed job to direct messages. The direct message will include the image's seed number and Job ID. If the envelope emoji is used for an image grid the grid will be sent as individual images. The ✉️ reaction only works with your own Jobs.

If you can't react to a job, it may be ephemeral. You'll see an `Only you can see this` warning at the bottom of the job, and reactions won't work. Use the `/show` command  to revive the job to react to it.

Job IDs are unique identifiers used for each image generated by Midjourney.  
Job IDs look like this: 9333dcd0-681e-4840-a29c-801e502ae424and can be found in the first part of all image filenames, in the URLs on the website, and in an image's filename.



------

## Chapter 12: ❌ Cancel and Delete

✉️ Send to Direct Messages

### Add the Bot to Your Server

Add the Bot to Your Server

Add the Midjourney Bot to any Discord Server to create with other subscribers, or make a personal Discord Server to organize your work.

Members of your private server must have their own Midjourney subscription to use the Midjourney Bot.

Midjourney images generated on private servers are still subject to Midjourney's Community Guidelines.

Images generated on private servers are still visible to other users on midjourney.com unless they're generated in Stealth Mode.

### Create Your Own Server

It's easy to create your own private Discord server to organize your work, notes and inspiration. Learn how to create your own Discord Server.

Add App

Select the Midjourney Bot from the User List, and then click Add App:

You can also add the Midjourney Bot to a server using the `Add to Server` button on its page in Discord's App Directory.

Choose your server from the Select a Server drop down

Click Authorize

### Bot Management

Restrict the Bot to Specific Channels

If you do not want the Midjourney Bot to be usable in specific channels, go to Edit Channel, select the Permissions tab, select @everyone under Roles/Members and Uncheck "Use Application Commands." Users who try to use the Midjourney Bot in a channel with these permissions disabled will not see the command.

For more granular control, go to Settings, select Integrations, the Permissions tab, the \+ for the Midjourney Bot, and Manage Integration. `slash command` permissions can then be set for individual roles and channels.

Get Status Updates and Announcements on Your Server

Follow the Midjourney Official Discord #announcements, #community updates, and #status channels on your server to stay up-to-date with Midjourney.  
  



------

## Chapter 13: Create Your Own Server

Add App

Bot Management

Restrict the Bot to Specific Channels

Get Status Updates and Announcements on Your Server

### Your Midjourney Account

Your Midjourney Account

Log into midjourney.com with your Discord or Google account to manage your subscription, view your previous images, and create new ones.

Returning to Midjourney?  
If you've used Midjourney in Discord in the past, choose the `Continue with Discord` option to log into the website.  
You can connect your Google account once you've logged in, but logging in with Google first may cause issues with your account.

Manage Your Profile

To manage your login information, visit the Manage Profile page on the website.

Connected Accounts

You'll see your existing login methods in the top section of the page. Click the `Connect Discord` or `Connect Google` button to add a new account. Once your new login is added, you. can use either to access midjourney.com.

All subscribers can generates images on the website.

To make images in Discord, you must have a Discord account connected.

You can't add a connected account if both the account you're logged in with and the account you're trying to add have Midjourney history, like past subscriptions or generated images (including trial images). If you try, you'll see an error message. Support can't merge these accounts.

You can only have one Discord account and one Google account connected at a time.

Disconnecting accounts is currently unavailable on the website. If you need to change which Discord or Google account you're using, email `billing@midjourney.com` for help.

The email address where you receive your subscription invoices may be different than your login email address(es).

Account Details

Additional details about your account are displayed in this section.

The email address you see here is from the first account you used to log into the website. It won't change or update after your account is created, even if you update your connected accounts. It's independent from your login and billing emails, and isn't used to contact you.

### Need Help?

If you have trouble logging into the website or managing your connected accounts, email `billing@midjourney.com` for help.



------

## Chapter 14: Manage Your Profile

Connected Accounts

Account Details

Need Help?

### Website Navigation

Website Navigation

At midjourney.com, you can create new images, manage your existing images, provide feedback to the team, and more!

Explore

Explore images generated by members of the Midjourney community.

Create

Create your own images using the web-creation interface.

Organize

Browse and organize all your Midjourney images.

Chat

Connect with the Midjourney community. Create images in shared spaces with everyone, or create private Rooms and invite your friends.

Tasks

Earn free Fast time with Rank Images and Surveys, or provide feedback to the team about features you'd like to see with Rate Ideas.

### Help

Click here for links to Midjourney documentation and support resources.

Updates

Catch up on Midjourney announcements, office hours news, and other changes. Set your personal notification preferences with the gear icon.

Light/Dark Mode

Toggle the website between light and dark viewing modes.

Account

Manage Subscription  
Subscribe or make changes to your current plan. You can also purchase additional Fast hours, check your plan details, and access your billing information.

Manage Uploads  
View and manage the images you've used as prompt references.

Sign Out  
Sign out of the website.



------

## Chapter 15: Explore

Create

Organize

Chat

Tasks

Help

Updates

Light/Dark Mode

Account

### Explore Page

Explore Page

From the Explore page, discover what's possible with Midjourney and find fun, exciting, and beautiful prompts to inspire your own creativity.

On the Explore page, you'll find images generated by other users and can quickly use those prompts and images to inspire your own unique creations.  
  
Create, Search, and View Images

Imagine Bar

Enter prompts, manage image references, and adjust your settings from the imagine bar. For more information on how website image creation works, visit the Create tab documentation.

Search Prompts

Search images generated by all Midjourney users. You can search for prompt text (for example `cyberpunk cats`) or parameters (like `--chaos 100`) to see how other Midjourney users are prompting.

Explore Page Sorting Options

By default, the Explore page shows a selection of random, recently generated images by other users. You can click the  Randomize button on the right to see a different set of images or use the sorting options to switch between different views:

Random: Random recent images from the Midjourney community

Hot: Trending images

Top (Day, Week, Month): The top-rated images from the chosen time period

Likes: Images from other users you've liked / ❤️ed

### Hover over an Image

When you mouse over an image on the Explore page, you'll see new details and options.

Username

The username of the Midjourney user who generated the image. Click on it to see their public Midjourney images.

Use as Image Prompt

Add this image as an image prompt to the imagine bar at the top of the page.

Edit Prompt

Add this prompt, including parameters and any image prompts or reference images, to the imagine bar at the top of the page.

Search Image

Search for other images like this one.

Like Image

Like / ❤️ other users' images so they appear in your "Liked" view.

### Click on an Image

When you click on a single image on the Explore page, you'll see additional details, including the prompt and parameters used to generate it.

1\. Prompt Text and Parameters

The full prompt, including the parameters, their values, and any reference images appear here.

2\. Menu Buttons

Options  
Manually copy prompt details, including the image URL and prompt, to use in your own generations.  
Use the "Report" option from this menu to report content you believe violates our Community Guidelines.

Search  
Find images similar to this one.

Like  
Like / ❤️ other users' images so they appear in your "Liked" view.

3\. Use

These buttons allow you to quickly and easily use this image in your own prompts.

Image: Use this image as an image prompt.

Style: Use this image as a Style Reference.

Prompt: Use this image's prompt

4\. Explore Feed

Click through to other nearby images from the Explore feed. You can also use your mouse wheel to scroll through these images from anywhere on the page.



------

## Chapter 16: Create, Search, and View Images

Imagine Bar

Search Prompts

Explore Page Sorting Options

Hover over an Image

Username

Use as Image Prompt

Edit Prompt

Search Image

Like Image

Click on an Image

1\. Prompt Text and Parameters

2\. Menu Buttons

3\. Use

4\. Explore Feed

### Create Page

Create Page

Generate Midjourney images directly on midjourney.com from the Create tab.

Creating and Searching Images

1\. Imagine Bar

Type your prompts here. Hit `Enter` to begin generating when you're ready. You can use parameters in your prompts the same way you would in Discord, or you can set them with the settings tool.

2\.  Image Prompts and References

Click the  button to open the image selection tool, where you can quickly and easily manage image prompts, character references, and style references. For more information about this tool, as well as about managing your uploaded images, visit the Using Image References on Web page.

3\.  Settings

Click the settings button to access your personal settings. Preferences you set here will automatically apply to all your prompts. If you want to use different settings for a single prompt, you can use --parameters in your prompt to override your settings.

For example if your default Speed is Relax, you can run a single job in Fast Mode by adding the `--fast` parameter to the end of your prompt.  
  
Website settings correspond to these features:

Setting NameFeature  
Image SizeAspect Ratio  
StylizationStylize  
WeirdnessWeird  
VarietyChaos  
ModeStyle  
VersionVersion  
SpeedRelax, Fast, or Turbo Mode  
StealthStealth Mode  
  
Your website and Discord settings are synced. This means that if you change your settings in one place, they'll change in the other too — including your generation speed (Relax, Fast, or Turbo Mode) and Stealth Mode settings. Double-check your settings to make sure they're set the way you want them before you generate images!  
Stealth Mode is only available on the Pro and Mega Plans.

4\.  Search

Search images in your Create feed. You can search by prompt text or parameters.

### Hovering over an Image or Prompt

As you generate images, they'll appear on your Create page with the most recent images at the top. Hovering over the generated images, or the prompt display on the right, will show some additional options.

Hovering over an Image

Hover over a generated image to reveal `Vary Subtle` and `Vary Strong` buttons. Learn more about the differences between subtle and strong variations on the Variations page.

Hovering over a Prompt

On the right side of the Create page, you'll see the prompts used to generate your images, including any parameters and image references. Hover over this section to see additional actions you can take with your images:

Rerun: Repeat this job.

Use: Copy this prompt to the imagine bar to quickly reuse or tweak it. Parameters and reference images used in the prompt will be copied too.

Hide: Hide this image from your Create feed. This will also hide the image from your Organize tab. It will still be visible to other users unless it's also Unpublished.

More: See a menu of additional options for this job:

Copy: Copy the prompt, job ID, seed, image, or image URL to your clipboard.  
Report: Report an image you believe violates the Community Guidelines.  
Publish /  Unpublish: Publish or Unpublish the image. This option only appears if your current plan includes Stealth Mode.  
Download: Download the selected image.  
Open in Discord: Jump to the location in Discord where this image was generated. For images generated on the website, a `Discord URL not available` error will appear if you click this button.

### Clicking on an Image

Click on an image in your Create page feed to see additional actions you can take with that image.

1\. Job Type

For non-imagine jobs, hover over this label to see a preview of the original set of images, with the parent image highlighted. Click on any image in the preview to jump to that image.

2\. Menu Buttons

Options  
Manually copy prompt details, including the image URL and prompt, to use in your own generations.

Download  
Download the selected image.

Search  
Search for other images like this one.

Like  
Like / ❤️ images so they appear in your "Liked" view.

3\. Create Feed

Click through to other nearby images from your Create feed. You can also use your mouse wheel to scroll through these images from anywhere on the page.

4\. Creation Actions

Use the buttons here to generate new images based on this one.

By default, not all of these options are shown. To customize which buttons appear for you in the light box, click "More options" and toggle the checkboxes to show or hide features.

To learn more about each of these actions, visit their feature pages: Vary, Upscale, Remix, Pan/Reframe, Zoom/Reframe, Repaint (Vary Region).

The `Use` buttons allow you to quickly add elements of this job's prompt to the imagine bar so you can reuse or tweak it. `Image` will add this image to your next job as an image prompt. `Style` will add the image as a Style Reference. `Prompt` will add the full prompt text, including parameters.

You can "Hide" images on the Midjourney website to remove them from your Archive. They'll no longer be visible to you unless you have the "Hidden" filter selected, but other users will still be able to view them (unless the image is also "Unpublished"). Hiding images is a good way to keep your Archive uncluttered. 

You can "Unhide" your hidden images to restore them to your archive anytime, so they're never lost.

By default, all images generated by Midjourney are "published, " or viewable by other users on midjourney.com. Users on plans that include Stealth Mode can generate "unpublished" images that aren't visible to other users.

You can publish your own unpublished images at any time on the website. If you have an active subscription that includes Stealth Mode, you can also unpublish any published images you have.

Learn more about Stealth Mode.

By default, all images generated by Midjourney are "published, " or viewable by other users on midjourney.com. Users on plans that include Stealth Mode can generate "unpublished" images that aren't visible to other users.

You can publish your own unpublished images at any time on the website. If you have an active subscription that includes Stealth Mode, you can also unpublish any published images you have.

Learn more about Stealth Mode.



------

## Chapter 17: Creating and Searching Images

1\. Imagine Bar

2\. Image Prompts and References

3\. Settings

4\. Search

Hovering over an Image or Prompt

Hovering over an Image

Hovering over a Prompt

Clicking on an Image

1\. Job Type

2\. Menu Buttons

3\. Create Feed

4\. Creation Actions

### The Web Editor

The Web Editor

The editor combines the Vary Region, Pan, and Zoom features into a single unifed web interface. Check out this video for a quick overview of what you can do, then read on to learn more!

Your browser does not support the video element. 

### Opening the Editor

Once you've generated an image you want to continue experimenting with, click on it to open the lightbox, then click the `Editor` button.

### Using the Editor

The Editor offers a streamlined web interface for continuing to experiment with your favorite Midjourney generations. You can Remix, Vary Region, Pan, and Zoom at the same time, in any combination.

When you're happy with the changes you've made, click `Submit` to begin generating your new image. Your new images will appear on the Create tab when they're finished.

The Editor can only be used with images generated with Midjourney.

Your browser does not support the video element. 

Editor Tools

1\.  Erase

Change parts of an image you like by Erasing the areas you want to re-generate. For the best results, select some extra space around the details you'd like to change so Midjourney has space to work. This is the default Editor tool. (This works smiliarly to the Vary Region feature.)

2\.  Restore

Refine the selections you made with Erase.

3\.  Undo /  Redo /  Reset

Undo the last change you made in the Editor, re-do the last change you un-did, or reset the interface to the way it was when you first opened the Editor.

4\. Brush Size

Control the diameter of the Erase / Restore brush to select larger or smaller parts of the image at a time.

5\. Scale

Move this slider down to expand your image in all directions. The farther down you go, the more space Midjourney will create around your original image. (This works similarly to the Zoom Out feature.)

6\. Aspect Ratio Selection

Choose a new aspect ratio for your image. You'll see an outline of the new shape of your image, and when you submit your job, Midjourney will expand the original to fit that space. (This works similarly to the Custom Zoom feature.

7\. Edit Prompt

Click and type here to make changes to your prompt. You can change the text, add or remove parameters, or add, remove, or change how you're using reference images. The `Reset Prompt` button will restore the prompt used to create your original image. (Changing your prompt this way functions similarly to the Remix feature.)

Prompt Editing Tip

It can be helpful to change your prompt to reflect the changes you want to make in the image â€` for example, if you're erasing details, it can be helpful to describe the details you want to see in the image instead, or if you're expanding the images, describe what you want to see in the new space.

8\.  Reposition

This icon appears in the middle of your existing image. Click and drag to reposition your existing image. Any new blank space will be filled when you submit your job. Any parts of the image that disappear won't be part of your new job.

9\. Size Bars

Instead of using the Scale slider or aspect ratio buttons, you can use the small bars that appear around the edges of your image to extend or crop your image. (This works similarly to the Pan feature.)

10\. Submit /  Back /  Close

Once you're happy with the changes you've made, `Submit` your job! You'll see the new generation added to your Create tab queue. Close the Editor to navigate to there and see your results.

The Back button will return you to the original image's lightbox view.



------

## Chapter 18: Opening the Editor

Using the Editor

Editor Tools

### External Editor

External Editor

Upload your own images to the External Editor and make changes using Midjourney's powerful tools.

The External Editor is only available to subscribers who meet at least one of the following requirements: have a yearly subscription, have been subscribed for at least 12 consecutive months with no interruptions, or have generated more than 10, 000 Midjourney jobs. If you'd like to upgrade your subscription, visit the Manage Subscription page.

The External Editor is a powerful new tool for unleashing your imagination. To maintain the same moderation standards we've set across Midjourney, we're introducing a few additional, necessary precautions.

By using the External Editor, you agree to the following rules in addition to our Terms of Service.

External Editor Access & Guidelines

The External Editor is only available to subscribers who meet at least one of the following requirements: have a yearly subscription, have been subscribed for at least 12 consecutive months with no interruptions, or have generated more than 10, 000 Midjourney jobs.

You must meet the age requirement in our Terms of Service.

You must follow all applicable laws, our Community Guidelines, and other policies.

We may remove content or restrict access at our discretion.

Your Responsibilities

You are responsible for all content you input, create, and share.

You must have the necessary rights to use and edit the images you upload.

If you disagree with these rules, do not use the External Editor.

You will likely encounter friction with our moderation — seemingly innocent prompts may be blocked by our filters. Blocked jobs don't cost you any credits. GPU time will only be deducted when you see your results.

We encourage you to use this tool and your imagination with joy, wonder, responsibility, and respect.

For additional information on policies, including privacy, payments, and disputes, refer to our Terms of Service.

Getting Started

External Editor Tools

To start, open the External Editor and choose an image from your Midjourney gallery, or use the  Edit from URL or  Edit Uploaded Image buttons to import an existing image.

Images you upload to the external editor are only visible to you — they won't appear anywhere on midjourney.com for other users.

Edit Tab

From the Edit tab, you can Remix, Vary Region, Pan, and Zoom, in any combination. When you're happy with the changes you've made, click `Submit Edit` to generate your new image.

1\.  Move / Resize  
Click this button to enable repositioning and scaling options on your starting image. You can click and drag the image to reposition it on your canvas, or use the bars and boxes that appear around the edges and corners of your image to extend or crop it. Any blank space you create, indicated by a grey-and-white checkerboard pattern, will be filled in with new details when you `Submit Edit`.

2\.  Erase  
Change parts of an image by Erasing the areas you want to re-generate. For the best results, select some extra space around the details you'd like to change so Midjourney has space to work. This is the default Editor tool. (This works similarly to the Vary Region feature.)

3\.  Restore  
Refine the selections you made with Erase.

4\.  Undo /  Redo /  Reset  
Undo the last change you made in the External Editor, re-do the last change you un-did, or reset the interface to the way it was when you first opened the External Editor.

5\.  Suggest Prompt  
Use the Describe tool to generate a prompt that matches your starting image.

6\. Brush Size  
Control the diameter of the Erase / Restore brush to select larger or smaller parts of the image at a time.

7\. Image Scale  
Move this slider down to expand your image in all directions. The farther down you go, the more space Midjourney will create around your original image. (This works similarly to the Zoom Out feature.)

8\. Aspect Ratio Selection  
Choose a new aspect ratio for your image. You'll see an outline of the new shape of your image, and when you submit your job, Midjourney will expand the original to fit that space. (This works similarly to the Custom Zoom feature.)

Retexture Tab

Retexturing estimates the shape of a scene and changes the overlying details, like lightning, materials, and surfaces. To retexture an image, click the Retexture Tab. You can edit your prompt in the imagine box at the top of the screen. For the best results, avoid using prompts that will clash with the structure of your starting image. When you're happy with the changes you've made, click `Submit Retexture` to generate your new image.

`Original Image`

`Retextured Image`

Export

Images generated in the External Editor don't automatically appear in your Organize or Create tabs. You can always find and organize them from the organization section of the Edit tab.

Upscale to Gallery  
Add the generated images to your main image gallery on the Organize and Create tabs.

Download Image  
Save your favorite images.

External Editor History

Your previously edited images and generations will appear here. Click  View All to return to the starting screen where you can see all your External Editor images, or  New to start fresh.



------

## Chapter 19: Getting Started

External Editor Tools

Edit Tab

Retexture Tab

Export

External Editor History

### Working with Images on Web

Working with Images on Web

On midjourney.com, you can easily upload and manage images you want to use as references in your prompts. Add images quickly as you work on the Create Page, or upload and manage your existing image references on the Manage Uploads page.

Image Upload and Selection

Click the  button in the Imagine bar on any page to open the image selection tool:

If the image you want to use is already shown, click on it to add it to your prompt. By default, it will be added as an image prompt, but you can also choose to use it as a style reference or character reference instead with the appropriate buttons.

There are several additional things you can do from this screen:

Choose a file or drop it here: If the image you want to use isn't already shown here, drag and drop it from your computer onto this box, or click and navigate through your files to find and add it. The image will appear in the grid of images to the right, and will also be added to your current prompt as an image reference.

Delete: Remove this images from your uploads. Jobs that used this image as a reference won't be affected.

Describe: Generate a list of subjects and descriptors based on the image. This works similarly to the `/describe` command in Discord, but instead of generating several full prompts, it will give you a variety of words and phrases to play with. Clicking on one of the generated phrases will add it to the end of your current prompt. Click the  Reroll button to generate new descriptions, and the  Back button to go back to the image selection tool.

### Using Image References

When you add an image to your prompt, it will be used as an image prompt by default, but you can hover over the image to choose a different option:

Character Reference: Use the selected image as a character reference.

Style Reference: Use the selected image as a style reference.

Image Prompt (Default): Use the image as an image prompt.

Remove: Remove this image from your current prompt.

To use the same image in multiple ways in a prompt (for example, as both a character reference and a style reference), `Shift + click` on the corresponding icons. A darker icon, like the  Image Prompt icon above, means you've chosen that reference type.

You can also use the buttons on the right to manage your reference images:

Lock / Unlock: Your image prompts are unlocked by default, meaning they'll clear every time you submit a prompt. Lock them to keep your selections between prompts. This will also lock the type of reference. The lock icon will turn red to indicate your image references are locked, and your selections will stay the same until you make changes or unlock them again. You can't lock or unlock references individually.

Delete: Removes all image references from your current prompt and closes the image selection tool.

### Manage Uploads Page

You can use the Manage Uploads page to organize the images you use frequently in your prompts.

Every image you use with Midjourney will be saved to your uploads and appear here. This includes images you use in prompts in Discord.

Other users can't access your image uploads page, but any image references you use will appear with your prompts on the website unless you're generating your images in Stealth Mode.

There are two views on the Manage Uploads page:

Visible: These images will appear in the image selection tool when you click the  button.

Hidden: These images are still saved in your uploads, but won't appear in the image selection tool.

You can hide a visible image or unhide a hidden image any time by hovering over it and clicking the  Hide or  Unhide button, or by clicking on it and using the larger buttons beneath the image on the right side of the page.

Delete: Remove an image permanently from your uploads. The image will still appear with any prompts that used it, and you'll be able to continue working with those jobs as normal.  
  



------

## Chapter 20: Image Upload and Selection

Using Image References

Manage Uploads Page

### Organize Page

Organize Page

Search and manage all the images you've generated with Midjourney from your Organize page.

All the images you've made with Midjourney appear on your Organize page, with the most recent images at the top. You can search or filter your Organize to find what you're looking for or create folders to keep your images organized. You can also use your Organize page to perform bulk actions, like downloading multiple images.

If you're generating your images in Stealth Mode, they will appear in your Organize page on the website, but they won't be visible to other Midjourney users.

Deleting an image by reacting to it with ❌ in Discord deletes that image from your Organize page. This is the only way to remove images completely from the website. Once you've ❌ed an image, it can't be restored.

Hiding an image on the website removes it from your Organize page, but those images can still be viewed by other Midjourney users. Hiding an image is not the same as Unpublishing it with Stealth Mode.

### Creating, Searching, and Organizing Images

1\. Imagine Bar

Enter prompts, manage image references, and adjust your settings from the imagine bar. For more information on how website image creation works, visit the Create Page documentation.

2\. Search Prompts

Search images you've created with Midjourney. You can search for prompt text (for example `cyberpunk cats`) or parameters (like `--chaos 100`). Unlike on the Explore page, only images you created will appear as search results here.

3\. Organize

Reveal or hide the organization sidebar on the right side of the screen.

4\. Timeline

Use the timeline to jump to a specific day's. Hover to see the dates, and click to jump to that day. More recent dates are at the top of the timeline, while older dates appear closer to the bottom of the page.

### Folders, Filters, and View Options

These options let you control which of your images you see on the Organize page, and how they're displayed.

Folders

Your existing folders will appear in the list here. To add a new folder to the list, click `Create Folder`. You can drag and drop images into folders to organize them, or use the bulk actions menu to move many images into a folder at once. You can also create smart folders, which will automatically include any images that match the search terms you set for them.

Smart Folders

When creating a new folder, you'll have the option to set it up as a smart folder. Smart folders will automatically include any images you generate that match your search terms, but you can't manually add or remove images from them.

Search Terms  

By default, only prompts that contain all of your search terms will be included in the smart folder, but it doesn't matter where or in what order those words appear in the prompts. For example, if you enter `cat dog` as your search terms, only images with both `cat` and `dog` somewhere in the prompt will be included. To include images with either cat or dog in the prompt, separate the terms with commas: `cat, dog`.

The smart folder search terms match partial strings. This means that if one of your search terms is a word that's also part of a longer word (for example, `cat` is part of `catapult`), any prompts you have with the longer word will also be included in the folder.

Filters

Use these preset options to filter your images.

You can check multiple boxes in each section to show images that match any of those options. For example, if you check "Liked" and "Unrated" in the `Rating` section, all Liked or Unrated images will display, but not Hidden ones.

You can check boxes in multiple sections to show images that match both sets of selections. For example, if you check "Liked" in the `Rating` section and "Landscape" in the `Image Size` section, only landscape images that you Liked will display.

Leaving all the boxes in a section unchecked is the same as checking all of them.

If you can't filter for the set of images you'd like to find using a combination of the preset filters, try using the search bar to find them.

If any of the filters are checked, you won't be able to see all your images. If you think images are missing, uncheck all the boxes on the right, and they should reappear.

View Options

Use these options to control how your images are displayed.

Layout

Square: All your images will appear as squares. In this layout, any landscape or portrait images you've generated will appear cropped.  
Full: All your images will appear uncropped, but they'll be shrunk to fit in the square layout. You'll see white space around any landscape or portrait images to fit them into the page grid, and details may be harder to see.

Image Size

Control how large the image tiles appear on the page. Larger image sizes will result in fewer images being shown on your screen at once.

### Bulk Selection and Actions

From your Organize page, you can take bulk actions on images you've generated, such as downloading them, assigning them to folders, or, if you have a plan that includes Stealth Mode, publishing and unpublishing them.

Bulk Selection

There are several ways to select multiple images from your Organize page:

Click the  next to a date to select all the images you created that day. You can select multiple days at once by clicking the  next to multiple dates.

Click any white space on the page and drag your cursor to select groups of images.

`Shift + Click` any individual images to add or remove them from your selection.

Click outside of a selection or click the  in the bulk actions menu to unselect all the images.

Bulk Actions Menu

Once you've selected a batch of images, a bulk actions menu will appear as a bar near the bottom of the page. The number displayed here is a count of all the images you've selected.

Download

Download the selected images.

More:

Like /  Unlike  
Like or Unlike all the selected images.

Hide /  Unhide  
Hide or Unhide all the selected images from your Organize page. They'll still be visible to other users unless they're unpublished.

Publish /  Unpublish  
Publish or Unpublish all the selected images from the website. These options only appear if your current plan includes Stealth Mode. Unpublished images will still be visible to you.

Add to Folder  
Add all the selected images to a folder you've created. Since you can't manually add or remove images from smart folders, they won't appear in the list of options here.

Cancel  
Clear your selection and close this bar.

You can "Hide" images on the Midjourney website to remove them from your Archive. They'll no longer be visible to you unless you have the "Hidden" filter selected, but other users will still be able to view them (unless the image is also "Unpublished"). Hiding images is a good way to keep your Archive uncluttered. 

You can "Unhide" your hidden images to restore them to your archive anytime, so they're never lost.

By default, all images generated by Midjourney are "published, " or viewable by other users on midjourney.com. Users on plans that include Stealth Mode can generate "unpublished" images that aren't visible to other users.

You can publish your own unpublished images at any time on the website. If you have an active subscription that includes Stealth Mode, you can also unpublish any published images you have.

Learn more about Stealth Mode.



------

## Chapter 21: Creating, Searching, and Organizing Images

1\. Imagine Bar

2\. Search Prompts

3\. Organize

4\. Timeline

Folders, Filters, and View Options

Folders

Filters

View Options

Bulk Selection and Actions

Bulk Selection

Bulk Actions Menu

### Command List

Command List

You can interact with the Midjourney Bot on Discord by typing a Command. Commands are used to create images, change default settings, monitor user info, and perform other helpful tasks.

Midjourney Commands can be used in any Bot Channel, on private Discord servers where the Midjourney Bot has been permitted to operate, or in a direct message with the Midjourney Bot.

Commands

/ask

Get an answer to a question.

/blend

Easily blend two images together.

/daily_theme

Toggle notification pings for the #daily-theme channel update

/describe

Writes four example prompts based on an image you upload.

/docs

Use in the official Midjourney Discord server to quickly generate a link to topics covered in this user guide!

/fast

Switch to Fast mode.

/feedback

Submit suggestions and ideas for Midjourney and rate ideas from others.

/faq

Use in the official Midjourney Discord server to quickly generate a link to popular prompt craft channel FAQs.

/help

Shows helpful basic information and tips about the Midjourney Bot.

/imagine 

Generate an image using a prompt

/info

View information about your account and any queued or running jobs.

/invite

Get the invite link for the Midjourney Discord server.

/list_tuners

Generate a list of all of the Style Tuner you have created.

/prefer option set

Create or manage a custom option.

/prefer option list

View your current custom options.

/prefer remix 

Toggle Remix mode.

/prefer suffix 

Specify a suffix to add to the end of every prompt.

/prefer variability

Toggle between High and Low variations when using the `V1` `V2` `V3` and `V4` buttons underneath an image grid.

/public

For Pro Plan Subscribers: switch to Public Mode

/relax 

Switch to Relax mode.

/settings 

View and adjust the Midjourney Bot's settings

/stealth

For Pro Plan Subscribers: switch to Stealth Mode

/shorten

Submit a long prompt and receive suggestions on how to make it more concise.

/show

Use an images Job ID to regenerate the job within Discord.

/subscribe

Generate a personal link for a user's account page.

/synonyms

Use in the official Midjourney Discord server to explore related words and phrases to try in your prompts.

/tune

Generate a Style Tuner based on your prompt. The Style Tuner lets you make your own Midjourney style and customize the look of your jobs.

/turbo

Switch to Turbo mode.

/userid

Get your Midjourney User ID

### Deprecated

/private (replaced with '/stealth')  
/pixels  
/idea

You can interact with the Midjourney Bot on Discord by typing aÂ Command. Commands are used to create images, change default settings, monitor user info, and perform other helpful tasks.

Midjourney Commands can be used in any Bot Channel, on private Discord servers where the Midjourney Bot has been permitted to operate, or in a direct message with the Midjourney Bot.

Bot Channels are Discord channels where the Midjourney Bot has been permitted to process Slash Commands. On the official Midjourney Discord, all channels in the Newcomer Rooms, Thread Channels, Themed Image Gen, and General Image Gen categories are Bot Channels.



------

## Chapter 22: Commands

/ask

/blend

/daily_theme

/describe

/docs

/fast

/feedback

/faq

/help

/imagine 

/info

/invite

/list_tuners

/prefer option set

/prefer option list

/prefer remix 

/prefer suffix 

/prefer variability

/public

/relax 

/settings 

/stealth

/shorten

/show

/subscribe

/synonyms

/tune

/turbo

/userid

Deprecated

### Blend

Blend

The `/blend` command allows you to upload 2â€`5 images quickly and then looks at the concepts and aesthetics of each image and merges them into a novel new image.

`/blend` is the same as using multiple image prompts with `/imagine`, but the interface is optimized for easy use on mobile devices.

`/blend` works with up to 5 images. To use more than 5 images in a prompt use image prompts with `/imagine`

`/blend` does not work with text prompts. To use text and image prompts together, use image prompts and text with `/imagine`

### `/blend` Options

After typing the `/blend` command, you will be prompted to upload two photos. Drag and drop images from your hard drive or add images from your photo library when using a mobile device. To add more images, select the `optional/options` field and select `image3`, `image4`, or `image5`. The `/blend` command may take longer to start than other commands because your images must be uploaded before the Midjourney Bot can process your request.

Blended images have a default 1:1 aspect ratio, but you can use the optional `dimensions` field to select between a square aspect ratio (1:1), portrait aspect ration (2:3), or landscape aspect ratio (3:2).

Custom suffixes are added to the end of `/blend` prompts, like any other `/imagine` prompt. Aspect ratios specified as part of the `/blend` command override aspect ratios within a custom suffix.

Blending Tip

For the best results, upload images that are the same aspect ratio as your desired result.

### How to Use `/blend`



------

## Chapter 23: /blend Options

How to Use /blend

### Describe

Describe

The `/describe` command allows you to upload an image and generate four possible prompts based on that image. Use the `/describe` command to explore new vocabulary and aesthetic movements.

The describe feature generates prompt suggestions that are inspirational and suggestive. It cannot be used to recreate an uploaded image exactly.

Describe works slightly differently between Discord and the website. Using the `/describe` commend in Discord will generate full prompts, while the website will offer suggestions of words and phrases to help you build your own prompts.

"Describing" the same image again will provide different suggestions.

### In Discord

Using the `/describe` Command

Use the `/describe` command wherever you use Midjourney Bot in Discord. You can provide an image to describe by entering the image's URL (select the `link` option; find more information about using image URLs in Discord here), or by selecting an image that's stored on your device (use the `image` option).  
  
Once the suggestions have generated, click the corresponding numbered buttons to `/imagine` that prompt. You'll have a chance to edit the text before submitting it.

You can also use the üîÑ button to run the `/describe` command on the same image again, or the `üéâ Imagine all` button to generate images with all four prompts at once (though you won't have the chance to edit them first).

An Example `/describe` in Discord

If you use the `/describe` command with the below image Midjourney Bot will suggest four prompts that may generate similar images:

1Ô∏è‚É£ drawing of a persian cat face in purple ballpoint pen on a white background, with purple fur, in the style of unknown artist.

2Ô∏è‚É£ A purple pencil drawing of a Persian cat, white background, in the style of John Beastman.

3Ô∏è‚É£ A purple pencil drawing of an adorable persian cat, with simple lines on a white background, featuring fine details and a beautiful composition in the style of a hyperrealistic work, with sharp edges and sharp focus.

4Ô∏è‚É£ A purple pencil drawing of an exotic shorthair cat, simple line art with a white background, fine lines and pastel colors create a soft and delicate atmosphere in this closeup portrait. The sketching style depicts the cat as cute and dreamy, with intricate details shown through detailed lines in a front view. The ink wash technique uses dark black tones with low saturation to create the style of the artist.

Legacy `/describe`

By default, the Discord `/describe` generates prompts that will work best with Version 6.

If you set your default Midjourney Version to 5.0 in Discord, `/describe` will generate shorter prompts that work better with older model versions.

On Web

From the Imagine Bar

Click the  icon in the imagine bar to access image reference options on the website. If the image you'd like to describe doesn't appear already, you can upload it from this view. Once it's uploaded, hover over the image to reveal the  icon, then click that to generate suggestions.

Instead of generating full prompt suggestions like `/describe` does in Discord, the website will give you a variety of words and phrases to play with. Clicking on one of the generated phrases will add it to the end of your current prompt. Click the  Reroll button to generate new descriptions, and the  Back button to go back to the image selection tool.



------

## Chapter 24: User Info

User Info

Use the `/info` command to see information about your current queued and running jobs, subscription type, renewal date, and more.

User ID

Your Midjourney User ID

Subscription

The Subscription section shows which plan you are subscribed to and your next renewal date.

Visibility Mode

Shows whether you are currently in Public or Stealth Mode. Stealth Mode is only available to Pro Plan subscribers.

Fast Time Remaining

Shows your remaining Fast GPU time for the month. Fast GPU time resets monthly and does not carry over.

Ranking Count

Shows your total number of ranked images, along with the number of images ranked in the last 30 days.

Lifetime Usage

Shows your lifetime Midjourney stats. Images include all types of generations (initial image grids, upscales, variations, remix, etc).

Fast, Turbo and Relaxed Usage

Shows your Fast, Turbo and Relaxed Mode usage.

Queued Fast and Relaxed Jobs

Lists all Jobs queued to run.

Running Jobs

Lists all Jobs currently running. A maximum of three jobs can run at the same time.

### Use the Info Command

Type `/info` in any Bot Channel or your Direct Messages. Only you will be able to see your Info popup.  

A Job is any action that uses the Midjourney Bot. Jobs include using `/imagine` to create an initial image grid, upscaling images, and creating variations of images.

A Job is any action that uses the Midjourney Bot. Jobs include using `/imagine` to create an initial image grid, upscaling images, and creating variations of images.

Bot Channels are Discord channels where the Midjourney Bot has been permitted to process Slash Commands. On the official Midjourney Discord, all channels in the Newcomer Rooms, Thread Channels, Themed Image Gen, and General Image Gen categories are Bot Channels.



------

## Chapter 25: User ID

Subscription

Visibility Mode

Fast Time Remaining

Ranking Count

Lifetime Usage

Fast, Turbo and Relaxed Usage

Queued Fast and Relaxed Jobs

Running Jobs

Use the Info Command

### Settings and Presets in Discord

Settings and Presets in Discord

The `/settings` command provides toggle buttons for common options like model version, style value, quality value, and upscaler version. Settings also has toggles for the `/stealth` and `/public` commands.

Parameters added to the end of a prompt will override selections made using `/settings`.

### Model Version Dropdown

Select the Midjourney Model Version to use when generating images. Use The Latest Model is the default selection and will always use the newest Midjourney Model Version.

`Use the latest Model (V6)` `6Ô∏è‚É£ Mjourney Model V6 [ALPHA]` `üåà Niji Model V6 [ALPHA]` `5Ô∏è‚É£ Mjourney Model V5.2` `5Ô∏è‚É£ Mjourney Model V5.1` `üçé Niji Model V5` `5Ô∏è‚É£ Mjourney Model V5.0` `üåà Niji Model V4` `4Ô∏è‚É£ Mjourney Model V4` `3Ô∏è‚É£ Mjourney Model V3` `2Ô∏è‚É£ Mjourney Model V2` `1Ô∏è‚É£ Mjourney Model V1`  
  
Style Raw Parameter

Midjourney Model Versions 5.1, 5.2, 6, and Niji 6 can be fine-tuned with the --style raw parameter to reduce the Midjourney default aesthetic. This toggle is not available if other model versions are selected.

`üîß Raw Mode`  
  
Stylize Parameter

The Midjourney Bot has been trained to produce images that favor artistic color, composition, and forms. The --stylize or --s parameter influences how strongly this training is applied. Low stylization values produce images that closely match the prompt but are less artistic. High stylization values create images that are very artistic but less connected to the prompt.

`üñåÔ∏è Stylize Low` `üñåÔ∏è Stylize Med` `üñåÔ∏è Stylize High` `üñåÔ∏è Stylize Very High`

Stylize Low = `--s 50`, Stylize Med = `--s 100`, Stylize High = `--s 250`, Stylize Very High = `--s 750`, 
  
Public and Stealth Mode

Toggle between Public and Stealth modes. Corresponds to the `/public` and `/stealth` commands.

`üßç‚Äç‚ôÇÔ∏èPublic`  
  
Remix Mode

Use Remix mode to change prompts, parameters, model versions, or aspect ratios between variations. Remix will take the general composition of your starting image and use it as part of the new Job. Remixing can help change the setting or lighting of an image, evolve a subject, or achieve tricky compositions.

`üéõÔ∏è Remix`  
  
High and Low Variation Mode

Toggle between High Variation and Low Variation mode.

`üé® High Variation Mode` `üé® Low Variation Mode`  
  
Sticky Style

Sticky Style will save the last `--style` code parameter used in your personal suffix, so you don't have to repeat the code on future prompts. Change codes by using a new `--style` or unselecting Sticky Style.

`üìå Sticky Style`

Turbo, Fast, and Relax Mode

Toggle between Turbo, Fast and Relaxed modes. Corresponds to the `/turbo`, `/fast`, and `/relax` commands and the `--turbo`, `--fast`, and `--relax` parameters.

`‚ö° Turbo Mode` `üêá Fast Mode` `üê¢ Relax Mode`  
  
Reset Settings

Return to default settings: `Use the latest Model (V6)` `üñåÔ∏è Stylize Med`. Your public/stealth mode, remix, variation, and generation speed preferences are unaffected.

`Reset Settings`  
  

### Automatically Direct Message Results

Use `/prefer auto_dm` to turn on or off automatic sending of finished jobs to your Direct Message.

### Custom Preferences

Create custom options using prefer commands to add commonly used parameters to the end of prompts automatically.

`/prefer suffix` specify a suffix to add to the end of every prompt.

`/prefer option` Create or manage a custom option.

`/prefer option list` View your current custom options.

Prefer Suffix

`/prefer suffix` automatically appends the specified suffix after all prompts.

Command example: `/prefer suffix` `--ar 16:9 --video`

To clear a set suffix, use the `/settings` command and select ` Reset Settings`, or use `/prefer suffix` again without adding the optional new_value field to the command.

Option Sets

`/prefer option set <name> <value>` command allows you to create a custom shortcut, adding multiple parameters or text snippets to your prompts.

`/prefer option set` `mine` `--chaos 5 --aspect 2:3` creates an option called "mine" that contains the chaos and aspect ratio parameters.

Using `/imagine prompt` `vibrant California poppies --mine`, is interpreted as `/imagine prompt` `vibrant California poppies --chaos 5 --aspect 2:3`.

You can use multiple option sets in the same prompt.

You can use a mix of prompt text and parameters in your option sets. If you do, all the parameters in the set must go at the end, just like in normal prompting.

Your option set will "expand" where it's placed in your prompts, so you'll need to put all your prompt parameters after your option set.

`/prefer option list` list all options created with `prefer option set.` Users can have up to 20 custom options.

To delete a custom option, use `/prefer option set` `<name to delete>` without adding the optional value field to the command.

Subscribers can work one-on-one with the Midjourney Bot in Discord's Direct Messages instead of a public channel. Images made within your direct messages are still subject to content and moderation rules and will be visible on your Midjourney website gallery.



------

## Chapter 26: Model Version Dropdown

Style Raw Parameter

Stylize Parameter

Public and Stealth Mode

Remix Mode

High and Low Variation Mode

Sticky Style

Turbo, Fast, and Relax Mode

Reset Settings

Automatically Direct Message Results

Custom Preferences

Prefer Suffix

Option Sets

### Show Job

Show Job

You can use the `/show` command with the unique Job ID to move a job to another server or channel, revive a lost job, or refresh an old job to make new variations, upscale, or use newer parameters and features.

`/show` only works on your own jobs.

### Find a Job ID

Job IDs are unique identifiers used for each image generated by Midjourney.  
Job IDs look like this: `9333dcd0-681e-4840-a29c-801e502ae424` and can be found in the first part of all image filenames, in the URLs on the website, and in an image's filename.

On the Web

You can find the Job ID of any image in your member gallery by selecting `Options` > `Copy` > `Job ID`.

From the URL

Job IDs are in the URL when viewing an image in your Midjourney gallery.  
https://www.midjourney.com/jobs/9333dcd0-681e-4840-a29c-801e502ae424?index=0.

From the File Name

Job IDs are the last part of the file name when viewing an image you have downloaded from your gallery.  
User_cat_cloud_spirit_9333dcd0-681e-4840-a29c-801e502ae424.png

Using a Discord Emoji Reaction

React to your completed job with the envelope emoji ✉️ and Midjourney Bot will send you a direct message with its Job ID. If you're not getting direct messages from the bot, check your Discord privacy settings.

### How to Use Show

Use the `/show <Job ID #>` in any Bot Channel to revive a Job.

Bot Channels are Discord channels where the Midjourney Bot has been permitted to process Slash Commands. On the official Midjourney Discord, all channels in the Newcomer Rooms, Thread Channels, Themed Image Gen, and General Image Gen categories are Bot Channels.



------

## Chapter 27: Find a Job ID

On the Web

From the URL

From the File Name

Using a Discord Emoji Reaction

How to Use Show

### Shorten

Shorten

The `/shorten` command analyzes your prompt, highlights some of your prompt's most influential words, and suggests unnecessary words you could remove. With this command, you can optimize your prompt by focusing on essential terms.

`/shorten` is not compatible with multi prompts or the `--no` parameter

### Analyze a Prompt with `/shorten`

The Midjourney Bot analyzes your prompt by breaking it down into smaller units known as tokens. These tokens can be phrases, words, or even syllables. The Midjourney Bot converts these tokens into a format it can understand. It uses them with the associations and patterns learned during its training to guide how your image is generated. Think of tokens as the building blocks that help the Midjourney Bot make sense of the input and create the desired visual output.

Long prompts with unnecessary words, lengthy descriptions, poetic phrases, or direct addressing of the bot ("Please make me an image, " "Thank you for your help, Midjourney Bot!") can lead to unexpected elements being added to your images.

The `/shorten` command can help you discover the most important words in your prompt and what words you can omit.

/shorten Command Example

If you want to create a pile of sprinkle covered donuts you might try the prompt:  
`Please create a whimsical majestic tower of donuts, intricately crafted and adorned with a mesmerizing array of colorful sprinkles. Bring this sugary masterpiece to life, ensuring every detail is rendered in stunning magical realism. Thank you!`

If you use `/shorten` command with the above prompt the Midjourney Bot will return the following information:

IMPORTANT TOKENS  
Please ~~create~~ a whimsical majestic tower of donuts, intricately crafted and adorned with a mesmerizing array of colorful sprinkles. Bring this sugary masterpiece to life, ~~ensuring every~~ detail is rendered in ~~stunning~~ magical realism. ~~Thank you!~~

SHORTENED PROMPTS  
1️⃣ Please, majestic tower of donuts, crafted, array of colorful sprinkles, sugary masterpiece, rendered, magical realism

2️⃣ Please, majestic tower of donuts, colorful sprinkles, sugary masterpiece, rendered, magical realism

3️⃣ majestic tower of donuts, colorful sprinkles, sugary, magical realism

4️⃣ majestic tower of donuts, colorful sprinkles, magical

5️⃣ tower of donuts, sprinkles

The most Important tokens in your prompt are highlighted in bold, the least important are ~~stikethroughed~~. You will also be given 5 possible shorter prompts based on this information.

### `Shortened Option 1️⃣ `

Please, majestic tower of donuts, crafted, array of colorful sprinkles, sugary masterpiece, rendered, magical realism

`Shortened Option 2️⃣ `

Please, majestic tower of donuts, colorful sprinkles, sugary masterpiece, rendered, magical realism

`Shortened Option 3️⃣ `

majestic tower of donuts, colorful sprinkles, sugary, magical realism

`Shortened Option 4️⃣ `

majestic tower of donuts, colorful sprinkles, magical

`Shortened Option 5️⃣ `

tower of donuts, sprinkles

Analyzing the Results

The shortest prompt, `Option 5️⃣ : tower of donuts, sprinkles` produced an image closest to the original goal. Many of the filler words like "whimsical, " "mesmerizing, " and "masterpiece" could be omitted. Learning that "tower" and "magical" were considered important tokens helps explain why some images were generated with fairytale castle elements. Learning this provided a clue that "magical" should be removed from the prompt if the goal was to create a stack of delicious donuts.

The `/shorten` command is a tool to help you explore how the Midjourney Bot interprets tokens and experiment with words, but it may not work for all subjects and styles of prompting.

### How to Use Shorten

Use the `/shorten <your prompt>` command in any Bot Channel to get information on your prompt

Bot Channels are Discord channels where the Midjourney Bot has been permitted to process Slash Commands. On the official Midjourney Discord, all channels in the Newcomer Rooms, Thread Channels, Themed Image Gen, and General Image Gen categories are Bot Channels.



------

## Chapter 28: Analyze a Prompt with /shorten

/shorten Command Example

Analyzing the Results

How to Use Shorten

### Parameter List

Parameter List

Parameters are options added to a prompt that change how an image generates. Parameters can change an image's Aspect Ratios, switch between Midjourney Model Versions, change which Upscaler is used, and lots more.

Parameters are always added to the end of a prompt. You can add multiple parameters to each prompt.

Using an Apple device?

Many Apple devices automatically change double hyphens (--) to an em-dash (—). Midjourney accepts both!

### Basic Parameters

Aspect Ratios

`--aspect`, or `--ar` Change the aspect ratio of a generation.

Chaos

`--chaos <number 0–100>` Change how varied the results will be. Higher values produce more unusual and unexpected generations.

Character Reference

Use images as character references in your prompt to create images of the same character in different situations.

Fast

`--fast` override your current setting and run a single job using Fast Mode.

Image Weight

`--iw <0–3>` Sets image prompt weight relative to text weight. The default value is 1.

No

`--no` Negative prompting, `--no plants` would try to remove plants from the image.

Quality

`--quality <.25, .5, or 1>`, or `--q <.25, .5, or 1>` How much rendering quality time you want to spend. The default value is 1. Higher values use more GPU minutes; lower values use less.

Random

`--style random`, add a random 32 base styles Style Tuner code to your prompt. You can also use `--style random-16`, `--style random-64` or `--style random-128` to use random results from other lengths of Style Tuners.

Relax

`--relax` override your current setting and run a single job using Relax Mode.

Repeat

`--repeat <1–40>`, or `--r <1–40>` Create multiple Jobs from a single prompt. `--repeat` is useful for quickly rerunning a job multiple times.

Seed

`--seed <integer between 0–4294967295>` The Midjourney bot uses a seed number to create a field of visual noise, like television static, as a starting point to generate the initial image grids. Seed numbers are generated randomly for each image but can be specified with the --seed or --sameseed parameter. Using the same seed number and prompt will produce similar ending images.

Stop

`--stop <integer between 10–100>` Use the `--stop` parameter to finish a Job partway through the process. Stopping a Job at an earlier percentage can create blurrier, less detailed results.

Style

`--style <raw>` Switch between versions of the Midjourney Model Version 5.1 and 5.2.  
`--style <4a, 4b, or 4c>` Switch between versions of the Midjourney Model Version 4.  
`--style <cute, expressive, original, or scenic>` Switch between versions of the Niji Model Version 5.  
Use the `/tune` command to create a Style Tuner and generate custom style codes.

Style Reference

Use images as style references in your prompt to influence the style or aesthetic of images you want Midjourney to make.

Stylize

`--stylize <number>`, or `--s <number>` parameter influences how strongly Midjourney's default aesthetic style is applied to Jobs.

Tile

`--tile` parameter generates images that can be used as repeating tiles to create seamless patterns.

Turbo

`--turbo` override your current setting and run a single job using Turbo Mode.

Video

`--video` Saves a progress video of the initial image grid being generated. Emoji react to the completed image grid with ✉️ to trigger the video being sent to your direct messages. `--video` does not work when upscaling an image.

Weird

`--weird <number 0–3000>`, or `--w <number 0–3000>` Explore unusual aesthetics with the experimental `--weird` parameter.

Default Values (Model Version 5.2)

Aspect RatioChaosQualitySeedStopStylize  
Default Value   
1:101Random100100  
Range   
any0–100.25 .5, or 1whole numbers 0–429496729510–1000–1000  
  
Aspect ratios greater than 2:1 are experimental and may produce unpredictable results.

Default Values (Model Version 6)

Aspect RatioChaosQualitySeedStopStylize  
Default Value   
1:101Random100100  
Range   
1:14–14:10–100.25 .5 or 1whole numbers 0–429496729510–1000–1000  
  

### Model Version Parameters

Midjourney routinely releases new model versions to improve efficiency, coherency, and quality. Different models excel at different types of images.

Niji

`--niji <4, or 5>` An alternative model focused on anime-style images.

Version

`--version <1, 2, 3, 4, 5.0, 5.1, 5.2, or 6>` or `--v <1, 2, 3, 4, 5.0, 5.1, 5.2, or 6>` Use a different version of the Midjourney algorithm.

### Legacy Parameters

Some parameters only work with earlier Midjourney Models.  
Read More about legacy parameters here.

### Compatibility

Model Version & Parameter Compatability

Affects initial generationAffects variations + remixVer. 6Ver. 5.2Niji 5  
Max Aspect Ratio✓✓anyanyany  
Chaos✓0–1000–1000–100  
Image Weight✓0–3   
default=1.5–2   
default=1.5–2   
default=1  
No✓✓✓✓✓  
Quality✓.25, .5, or 1.25, .5, or 1.25, .5, or 1  
Repeat✓✓✓✓  
Seed✓✓✓✓  
Stop✓✓10–10010–10010–100  
Stylerawrawcute, expressive, original   
and scenic  
Stylize✓0–1000   
default=1000–1000   
default=1000–1000   
default=100)  
Tile✓✓✓✓✓  
Video✓✓✓✓  
Weird✓0–3000   
default=00–1000   
default=00–1000   
default=0  
  
The Midjourney Bot processes jobs on high-end GPUs. Each minute that it takes to complete a job is a GPU minute. You have a limited amount of GPU minutes when in Fast Mode. Because image generations may be processed on multiple GPUs simultaneously, GPU minutes are not directly connected to the time you wait for an image to generate.



------

## Chapter 29: Basic Parameters

Aspect Ratios

Chaos

Character Reference

Fast

Image Weight

No

Quality

Random

Relax

Repeat

Seed

Stop

Style

Style Reference

Stylize

Tile

Turbo

Video

Weird

Default Values (Model Version 5.2)

Default Values (Model Version 6)

Model Version Parameters

Niji

Version

Legacy Parameters

Compatibility

Model Version & Parameter Compatability

### Aspect Ratios

Aspect Ratios

The `--ar` (or `--aspect`) parameter changes the aspect ratio of the generated image. An aspect ratio is the width-to-height ratio of an image. It is typically expressed as two numbers separated by a colon, such as 7:4 or 4:3.

A square image has equal width and height, described as a 1:1 aspect ratio. The image could be 1000px × 1000px, or 1500px × 1500px, and the aspect ratio would still be 1:1. A computer screen might have a ratio of 16:10. The width is 1.6 times longer than the height. So the image could be 1600px × 1000px, 4000px × 2000px, 320px x 200px, etc.

The default aspect ratio is 1:1.

`--ar` must use whole numbers. Use 139:100 instead of 1.39:1.

The first number represents width, while the second number represents height. For portrait (tall) images, the second number should be larger. For landscape (wide) images, the first number should be larger.

The aspect ratio impacts the shape and composition of a generated image.

Some aspect ratios may be slightly changed when upscaling.

Older Midjourney Version Models may not support all aspect ratios.

### Aspect Ratio Comparison

prompt example: `/imagine prompt` `vibrant California poppies --ar 5:4`

Extremely wide and tall aspect ratios are experimental and may produce unpredictable results.

Common Midjourney Aspect Ratios

`--ar 1:1` Default aspect ratio.  
`--ar 5:4` Common frame and print ratio.  
`--ar 3:2` Common in print photography.  
`--ar 7:4` Close to HD TV screens and smartphone screens.

### Changing the Aspect Ratio of an Image

Do you love an image you have generated but wish it was taller or wider? You can use the Pan and Zoom features to adjust the aspect ratio of your images in different ways. For more information, check out these pages: Pan, Zoom.

### How to Set the Aspect Ratio

Use Aspect Ratio Parameters

Add `--aspect <value>:<value>`, or `--ar <value>:<value>` to the end of your prompt on Discord or in the imagine bar on the website:

Website Settings

On the website, you can also set a default aspect ratio using the Settings button in the imagine bar:

The `Portrait` button will set your aspect ratio to 3:4. The `Landscape` button will set it to 4:3. You can adjust the slider left for taller aspect ratios, up to 1:2, or right for wider ones, up to 2:1.

The value you set here will apply to all your prompts unless you specify a different value using the `--aspect` or `--ar` parameter in an individual prompt.

Not all aspect ratios are supported by the slider, but you can use the `--ar` parameter at the end of your prompt to set any ratio you'd like.



------

## Chapter 30: Aspect Ratio Comparison

Common Midjourney Aspect Ratios

Changing the Aspect Ratio of an Image

How to Set the Aspect Ratio

Use Aspect Ratio Parameters

Website Settings

### Chaos

Chaos

The `--chaos` or `--c` parameter influences how varied the initial image grids are. High `--chaos` values will produce more unusual and unexpected results and compositions. Lower `--chaos` values have more reliable, repeatable results.

`--chaos` accepts values 0â€`100.  
The default `--chaos` value is 0.

### The Influence of Chaos on Jobs

No `--chaos` value

Using a very low `--chaos` value, or not specifying a value, will produce initial image grids that are similar.

prompt example: `/imagine prompt:` `a silver seashell inlaid with pink and green accents --c 0`

Low `--chaos` values

Using a low `--chaos` value will produce initial image grids that are slightly varied.

prompt example: `/imagine prompt:` `a silver seashell inlaid with pink and green accents --c 10`

Moderate `--chaos` values

Using a moderate `--chaos` value will produce initial image grids that are varied.

prompt example: `/imagine prompt:` `a silver seashell inlaid with pink and green accents --c 25`

High `--chaos` Values

Using a higher `--chaos` value will produce initial image grids that are more varied and unexpected.

prompt example: `/imagine prompt:` `a silver seashell inlaid with pink and green accents --c 50`

Very High `--chaos` Values

Using extremely high `--chaos` values will produce initial image grids that are varied and have unexpected compositions or elements.

prompt example: `/imagine prompt:` `a silver seashell inlaid with pink and green accents --c 80`

### How to Change the Chaos Value

Use the `--chaos` or `--c` Parameter

Add `--chaos <value>` or `--c <value>` to the end of your prompt on Discord or in the imagine bar on the website:

Website Settings

On the website imagine bar Settings, Chaos is called Variety. You can set a default Variety value using the Settings button in the imagine bar:

Adjust the slider left for lower values and right for higher values.

The value you set here will apply to all your prompts unless you specify a different value using the `--chaos` or `--c` parameter in an individual prompt.



------

## Chapter 31: The Influence of Chaos on Jobs

No --chaos value

Low --chaos values

Moderate --chaos values

High --chaos Values

Very High --chaos Values

How to Change the Chaos Value

Use the --chaos or --c Parameter

Website Settings

### Character Reference

Character Reference

You can use images as character references in your prompt to create images of the same character in different situations.

To add character references to a prompt, use the --cref parameter with the web address (URL) where the image is stored online: `--cref URL`

Character references work best when using images generated by Midjourney that feature a single character.

`--cref` is not designed to be used with photographs of real people, and will distort them.

Precise details like specific freckles or t-shirt logos aren't likely to be copied.

`--cref` can be used with Midjourney and Niji Version 6, and can be combined with `--sref`.

You can use multiple character references in a single prompt, but probably don't need to.

Any regular image prompts must go before `--cref`.

Privacy Notes

Upload images in your direct messages with the Midjourney Bot to prevent other server users from seeing an image.

Image prompts and references are visible on the Midjourney website unless you're generating in Stealth Mode.

See the Image Prompts page for help using image URLs in your prompts on Discord, or the Using Image References on Web page for help using all kinds of image references on midjourney.com.

### Examples

`Reference Image: BlueHairGuy.png`

`Prompt: illustration of a man sitting in a cafe`

`Prompt: illustration of a man sitting in a cafe --cref https://url.com/BlueHairGuy.png`

### Character Weight Parameter

Use the character weight parameter `--cw` to set the strength of characterization. `--cw` accepts values from 0 to 100. `--cw 0` focuses on the character's face only. Higher values use the character's face, hair, and clothing. `--cw 100` is default.

prompt example: `/imagine prompt` `illustration of a man sitting in a cafe --cref https://url.com/BlueHairGuy.png`

`--cw 0`

`--cw 50`

`--cw 100`

### Combining Style and Character References

To maintain a consistent style while using a character reference, you can combine the `--sref` and `--cref` parameters. See the Style Reference page for more information on using --sref.

`/imagine prompt` `illustration of a man sitting in a cafe --cref https://url.com/BlueHairGuy.png --sref https://url.com/BlueHairGuy.png`



------

## Chapter 32: See the Image Prompts page for help using image URLs in your prompts on Discord, or the Using Image References on Web page for help using all kinds of image references on midjourney.com

Examples

Character Weight Parameter

Combining Style and Character References

### No

No

The No parameter tells the Midjourney Bot what not to include in your image.

`--no` accepts multiple words separated with commas: `--no item1, item2, item3, item4`

`--No` Comparison

`still life gouache painting`

a range of objects appear in the still life

`still life gouache painting --no fruit`

The still life has fewer fruits

`--no` vs. Don't

The Midjourney Bot considers every word in the prompt as a potential element for the image. Prompting `still life gouache painting without any fruit` or `still life gouache painting, please dont add fruit!` are more likely to produce pictures that include fruits because the relationship between "without" or "don't" and the "fruit" is not interpreted by the Midjourney Bot in the same way a human reader would understand it. To improve your results, focus your prompt on what you do want to see in the image and use the "--no" parameter to specify concepts you don't want to include.

`still life gouache painting`

A range of objects appear in the still life.

`still life gouache painting, please don't add fruit!`

More fruit is present in the final image.

Multi Prompting

The `--no` parameter is the same as weighing part of a multi prompt to "-.5" `still life gouache painting:: fruit::-.5` is the same as `still life gouache painting --no fruit`.

### How to Use the No Paramter

Add `--no item1, item2, item3` to the end of your prompt.



------

## Chapter 33: --No Comparison

--no vs. Don't

Multi Prompting

How to Use the No Paramter

### Personalization

Personalization

Create custom image styles with personalized profiles and moodboards using `--p`

What is Personalization?

Personalization is like your personal style assistant for creating images with Midjourney! When you interact with images by liking or ranking them, Midjourney learns what kind of visuals you enjoy. Then, when you use personalization in your prompt, Midjourney uses what it's learned to create images that match your tastes. It's like telling Midjourney, "Remember how I liked those kinds of images? Make more like that!"

Personalization is compatible with Midjourney Version 6, 6.1, and Niji 6. Niji personalization is entirely separate and handled on the Niji website.

Personalization Profiles

Personalization profiles are like setting up different 'looks' or 'themes' for the images you create with Midjourney. Each profile can represent a different style or mood that you like and you can have multiple profiles for different tastes. Create and manage your personalization profiles on your Personalize page.

Global Profile  
If you were already using personalization when profiles were introduced, this profile will hold all that personalization and style data you‚Äôve been accumulating. It's also the only profile that changes when you like ‚ù§Ô∏è images from other users on the Explore page.

Standard Profiles  
These are extra profiles you can create to focus on specific styles. You rank pairs of images to tell Midjourney what you like.

Moodboard Profiles  
You create these by selecting specific images that inspire you and set a particular mood or vibe. They act like vision boards for ideas you want to capture. You can upload your own images, provide image URLs, or select images from your gallery.

When you rank image aesthetics on the website, you will need to pick which profile you are ranking for from your Personalization page. New ranking data will only apply to the profile you select.

### Personalization Walkthrough

Head to the Personalize page on the Midjourney website to view and manage your personalization profiles. This is your starting point for customizing your image styles.

¬†

¬†

¬†

¬†

¬†

¬†

Turn on personalization using the toggle switch. This will automatically add your default personalization profile to all your prompts, allowing your images to reflect your personal style.

To create a standard profile, click the "Create Standard Profile" button. This will take you to a new page where you'll rank pairs of images. Choose the image you like best between the two options. Continue ranking until you've unlocked your profile, which is necessary before you can start using it.

To create a moodboard profile, click the "Create Moodboard" button. This will take you to a blank moodboard page. Here, you can upload images from your computer or device, add images from URLs, or add images from your Midjourney gallery.

Click Copy Code to add your profile ID to the Imagine bar and copy it to your clipboard. If you've turned on personalization, you can also use the checkbox on your favorite profile to automatically include its ID in your prompts when using the website. This makes it easy to apply your chosen style automatically.  

### Using Personalization

On Web

Add `--p` to the end of your prompt in the Imagine bar. This will automatically apply your default personalization profile to your prompt.

To use a specific profile, click Copy Code from your Personalization page to add its profile ID to the end of your prompt (example: `--p pID`). You can also use a specific code `--p CODE`

You can choose a default personalization setting for all your images in the settings panel. To do this, click the settings  button in the Imagine bar, turn Personalize on, and select your profile using the dropdown menu. Once you set it, this will apply to all your future prompts.

In Discord

Add `--p` to the end of your prompt in Discord. This will automatically apply your default personalization profile to your prompt.

To use a specific profile, copy its ID from your Personalization page using the Copy Code button and add it to the end of your prompt (example: `--p pCODE`). You can also use a specific code `--p CODE`

On Discord you can use the `üôã Personalization` button in your Midjourney settings (run the `/settings` command wherever you use the bot) to automatically add the `--p` parameter to all your prompts.

You'll only be able to use personalization once you've ranked enough image aesthetic pairs and/or ‚ù§Ô∏èed enough images on the website. If you try to use `--p` without enough data, you'll see an error message directing you to do more ranking.

### Personalization Codes

Your personalization profiles will grow and change as you keep liking, ranking, and adding more image data. As your profile updates, it will generates new codes. These codes act like labels for the different versions of your style profile, helping you keep track of how your preferences have evolved. Copy the ID from your profile to use the latest version. To find older codes, you can use the `/list_personalize_codes` command in Discord or revisit your previous prompts to see the codes you used before.

Note: When using a profile code it will automatically convert from `--p pID` to `--p code` when you submit your prompt.

### Managing Your Profiles

You can manage your profiles by renaming or deleting them. To do this, hover your mouse over a profile and use the pencil  button to rename it or the trash can  button to delete it. If you choose to delete a profile, it will be removed from your profiles list, and you won't be able to add any new data to it. However, any codes that were already created from that profile will still work, allowing you to continue using its style in future prompts.

### Stylize with Personalization

When using personalization, the `--stylize` parameter controls how much of your personalization is applied to the image. A lower stylize value will limit the personalization, while a higher value will increase it. The stylize parameter accepts values from 0 to 1000. The default is 100.



------

## Chapter 34: What is Personalization?

Personalization Profiles

Personalization Walkthrough

Using Personalization

On Web

In Discord

Personalization Codes

Managing Your Profiles

Stylize with Personalization

### Quality

Quality

Control how much time your images take to generate with `--quality` or `--q`

A lower `--q` value means your images generate faster. These jobs consume less GPU time, but the resulting images will be less detailed. This can be useful for experimenting with new prompts, so you can hone your ideas more quickly.

Using a higher `--q` value costs more GPU time and can improve image textures and detail, but may reduce the coherency of your images.

Version Quality Compatibility

Model VersionQuality .25Quality .5Quality 1Quality 2  
Version 6.1x✓✓✓  
Version 6.0✓✓✓x  
Version 5.2✓✓✓x  
niji 5✓✓✓x  
  
`--quality` does not impact the resolution of your generated images, and does not guarantee the resulting images will be "better" or "worse" than an image generated with a higher or lower value — it only influences how much GPU time Midjourney spends creating them.

The default `--quality` value is 1.

Other values are rounded to the closest available option for the model version you're using.

`--q` only influences the initial image generation, not variations or upscales.

### Quality Comparison

Prompt example: `/imagine prompt` `intricate woodcut of a peony`

`--quality .5`

quickest, but least detailed results

`--quality 1`

the default setting

`--quality 2`

slower, but more detailed results

### How to Use the Quality Parameter

Use the `--quality` or `--q` Parameter

Add `--quality <value>` or `--q <value>` to the end of your prompt.



------

## Chapter 35: Version Quality Compatibility

Quality Comparison

How to Use the Quality Parameter

Use the --quality or --q Parameter

### Repeat

Repeat

The `--repeat` or `--r` parameter runs a Job multiple times. Combine `--repeat` with other parameters, like --chaos to increase the pace of your visual exploration.

`--repeat` accepts values 2–4 for Basic subscribers  
`--repeat` accepts values 2–10 for Standard subscribers  
`--repeat` accepts values 2–40 for Pro and Mega subscribers  
The `--repeat` parameter can only be used in Fast and Turbo GPU mode.

### Use the `--repeat` or `--r` Parameter

Add `--repeat <value>` or `--r <value>` to the end of your prompt.

A Job is any action that uses the Midjourney Bot. Jobs include using `/imagine` to create an initial image grid, upscaling images, and creating variations of images.

There are two modes for image generation, Fast Mode and Relax Mode. Fast Mode tries to give you a GPU instantly. It's the highest-priority processing tier and uses your subscription's monthly GPU time. Relax Mode queues your generation behind others based on how much you've used the system. Relax Mode wait times are variable and usually range from 1–10 minutes.

By default, your images will be generated using Fast mode. You can switch to Relax if you have a Standard or Pro subscription.



------

## Chapter 36: Seeds

Seeds

The Midjourney bot uses a seed number to create a field of visual noise, like television static, as a starting point to generate the initial image grids. Seed numbers are generated randomly for each image but can be specified with the `--seed` parameter. If you use the same seed number and prompt, you will get similar final images.

`--seed` accepts whole numbers 0–4294967295.

`--seed` values only influence the initial image grid.

Identical `--seed` values using Model Versions `1`, `2`, `3`, `test`, and `testp` will produce images with similar composition, color, and details.

Identical `--seed` values using Model Versions `4`, `5`, `6` and `niji` will produce nearly identical images.

Seed numbers are not static and should not be relied upon between sessions.

### Seed Parameter

If no Seed is specified, Midjourney will use a randomly generated seed number, producing a wide variety of options each time a prompt is used.  
  
Jobs run three times with random seeds:

prompt example: `/imagine prompt` `celadon owl pitcher`

Jobs run three times with `--seed 12345`:

prompt example: `/imagine prompt` `celadon owl pitcher --seed 123`

### How to Find a Job's Seed Number

Use a Discord Emoji Reaction

Find the seed number of a Job in discord by reacting with an ✉️ envelope emoji to a Job.

Use The Show Command to Bring Back Old Jobs

To get the seed number for a past image, copy the job ID  and use the `/show <Job ID #>` command with that ID to revive the Job. You can then react to the newly regenerated Job with an ✉️ envelope emoji.

### How To Change Seed Numbers

Use the `--seed` Parameter

Add `--seed <value>` to the end of your prompt.

A Job is any action that uses the Midjourney Bot. Jobs include using `/imagine` to create an initial image grid, upscaling images, and creating variations of images.



------

## Chapter 37: Seed Parameter

Jobs run three times with random seeds:

Jobs run three times with --seed 12345:

How to Find a Job's Seed Number

Use a Discord Emoji Reaction

Use The Show Command to Bring Back Old Jobs

How To Change Seed Numbers

Use the --seed Parameter

### Stop

Stop

Use the `--stop` parameter to finish a Job partway through the process. Stopping a Job at an earlier percentage can create blurrier, less detailed results.

`--stop` accepts values: 10â€`100.  
The default `--stop` value is 100.  
`--stop` does not work while Upscaling.

### Stop Comparison

prompt example: `/imagine prompt` `splatter art painting of acorns --stop 90`

--stop 10

--stop 20

--stop 30

--stop 40

--stop 50

--stop 60

--stop 70

--stop 80

--stop 90

--stop 100

prompt example: `/imagine prompt` `a wooden inlay oak leaf --stop 50`

--stop 10

--stop 20

--stop 30

--stop 40

--stop 50

--stop 60

--stop 70

--stop 80

--stop 90

--stop 100

### How to Change the Stop Percentage

Use the `--stop` Parameter

Add `--stop <value>` to the end of your prompt.



------

## Chapter 38: Stop Comparison

How to Change the Stop Percentage

Use the --stop Parameter

### Style

Style

The `--style` parameter replaces the default aesthetic of some Midjourney Model Versions.

Model Versions 6, 5.2, 5.1 and Niji 6 accept `--style raw`.

### The Effects of `--style raw`

`--style raw` uses an alternative model that may work well for users already comfortable with prompting who want more control over their images. Images made with `--style raw` have less automatic beautification applied, which can result in a more accurate match when prompting for specific styles.

Model Version 6

`--v 6`

black and white oak tree icon

`--v 6 --style raw`

black and white oak tree icon --style raw

`--v 6`

child's crayon drawing of a cat

`--v 6 --style raw`

child's crayon drawing of a cat --style raw

### Model Version 5.2

`--v 5.2`

ice cream icon

`--v 5.2 --style raw`

ice cream icon --style raw

`--v 5.2 `

child's drawing of a cat

`--v 5.2 --style raw`

child's drawing of a cat --style raw

### How to Use Styles

Use the `--style` Parameter

Add `--style <style name>` to the end of your prompt on Discord or in the imagine bar on the website:

Use the Settings Command

Type `/settings` and select `ðŸ`§ RAW Mode` from the menu to append `--style raw` to all prompts.

Website Settings

You can choose between Standard and Raw styles as your default "Mode" with buttons in the website Settings menu:

Your current default style will be highlighted in red.

If `Standard Mode` is your default style, you can override it by adding `--style raw` to individual prompts. If `Raw Mode` is your default, you'll need to switch back to `Standard Mode` in your setings to turn it off.



------

## Chapter 39: The Effects of --style raw

Model Version 6

Model Version 5.2

How to Use Styles

Use the --style Parameter

Use the Settings Command

Website Settings

### Style Reference

Style Reference

You can use images as style references in your prompt to influence the style or aesthetic of images you want Midjourney to make.

To add style references to a prompt, use the --sref parameter with the web address (URL) where the image is stored online: `--sref URL`

Style references only apply to prompts that include text‚Äìthey can‚Äôt be used with image-only prompts.

You can also use prompt text to reinforce your style reference, and may need to with tricky styles.

Any regular image prompts must go before `--sref`

You can use multiple style references: `--sref URL1 URL2 URL3`

You can also use `--sref random` to apply a random style to your images.

`--sref` can be used with Midjourney and Niji Version 6

Privacy Notes

Upload images in your direct messages with the Midjourney Bot to prevent other server users from seeing an image.

Image prompts and references are visible on the Midjourney website unless you're generating in Stealth Mode.

See the Image Prompts page for help using image URLs in your prompts on Discord, or the Using Image References on Web page for help using all kinds of image references on midjourney.com.

### Examples

`Reference Image: CatSketch.png`

`Prompt: a cat`

`Prompt: a cat --sref https://url.com/CatSketch.png`

### Style Weight Parameter

Use the style weight parameter `--sw` to set the strength of stylization. `--sw` accepts values from 0 to 1000. `--sw 100` is default.

prompt example: `/imagine prompt` `a cat --sref https://url.com/CatSketch.png`

` `--sw 50` `

` `--sw 100` `

` `--sw 800` `

Individual style references can also be assigned different weights: `--sref URL1::2 URL2::1 URL3::1`

See the Multi Prompts page for more information about the relative importance between parts of a prompt.

### Style Reference Versions

There are four versions of the style reference feature. Use the `--sv` parameter to choose between them. `--sv 4` is default.

`--sv 1` The original style reference algorithm, more ‚Äúvibey‚Äù  
`--sv 2` The second iteration of style references  
`--sv 3` An updated version of the more ‚Äúvibey‚Äù --sv 1  
`--sv 4` An updated version of --sv 2

` `--sv 1` `

` `--sv 2` `

` `--sv 3` `

` `--sv 4` `

### Random Style References

You can use --sref random to randomly select a style from an abstract range that Midjourney knows how to generate.

Rerolling üîÑ or making variations of a job with --sref random will generate different images with the same random style as the parent grid.

Each job from a permutation or `--repeat` prompt with --sref random will use a different random style.

After you submit your prompt, "random" will be replaced with a style reference seed you can use to replicate that style in future prompts.

`--sw` works with random style references to control how strongly the random style influences the results.

You can't combine random style references or style reference seeds with each other or with URL style references.

Examples:

` `a cat --sref random` `

` `a cat --sref random` `

` `a cat --sref random` `

` `a cat --sref random` `

Style Reference Seeds

In your completed job, the "random" value will be replaced with a style reference seed number: `--sref random` ‚û°Ô∏è `--sref 762351716`. You can use that style reference seed in future prompts to generate images in the same style.

`a cute cat --sref 762351716`

`a cute rubber duck --sref 762351716`

`a cute owl --sref 762351716`

`a cute turtle --sref 762351716`



------

## Chapter 40: See the Image Prompts page for help using image URLs in your prompts on Discord, or the Using Image References on Web page for help using all kinds of image references on midjourney.com

Examples

Style Weight Parameter

Style Reference Versions

Random Style References

Examples:

Style Reference Seeds

### Stylize

Stylize

The Midjourney Bot has been trained to produce images that favor artistic color, composition, and forms. The `--stylize` or `--s` parameter influences how strongly this training is applied. Low stylization values produce images that closely match the prompt but are less artistic. High stylization values create images that are very artistic but less connected to the prompt.

`--stylize`'s default value is 100 and accepts integer values 0‚Äì1000 when using the current models

### Common Stylize Settings

Influence of Stylize on Model Version 6

prompt example: `/imagine prompt` `child's drawing of a cat --s 100`

`--stylize 0`

`--stylize 50`

Equal to `üñåÔ∏è Style Low`

`--stylize 100` (default)

Equal to `üñåÔ∏è Style Med`

`--stylize 250`

Equal to `üñåÔ∏è Style High`

`--stylize 500`

`--stylize 750`

Equal to `üñåÔ∏è Style Very High`

prompt example: `/imagine prompt` `colorful risograph of a fig --s 100`

`--stylize 50`

Equal to `üñåÔ∏è Style Low`

`--stylize 100` (default)

Equal to `üñåÔ∏è Style Med`

`--stylize 250`

Equal to `üñåÔ∏è Style High`

`--stylize 750`

Equal to `üñåÔ∏è Style Very High`

### How to Use Stylize

Use the Stylize Parameter

Add `--stylize <value>` or `--s <value>` to the end of your prompt on Discord or in the imagine bar on the website:

Use the Discord Settings Command

Type `/settings` and select your preferred stylize value from the menu.

`üñåÔ∏è Style Low` `üñåÔ∏è Style Med` `üñåÔ∏è Style High` `üñåÔ∏è Style Very High`

Website Settings

You can set a default Stylization using the Settings button in the imagine bar:

Adjust the slider left for lower values and right for higher values.

The value you set here will apply to all your prompts unless you specify a different value using the `--stylize` or `--s` parameter in an individual prompt.



------

## Chapter 41: Common Stylize Settings

Influence of Stylize on Model Version 6

How to Use Stylize

Use the Stylize Parameter

Use the Discord Settings Command

Website Settings

### Tile

Tile

The `--tile` parameter generates images that can be used as repeating tiles to create seamless patterns for fabrics, wallpapers and textures.

`--tile` works with Model Versions `1` `2` `3` `test` `testp` `5` `5.1` `5.2` and `6`.  
`--tile` only generates a single tile. Use a pattern making tool like this Seamless Pattern Checker  to see the tile repeat.

### Tile Examples

`prompt` `a pattern of pink and blue striped river stones --tile`  

`prompt` `a pattern of colorful watercolor fall leaves --tile`  

### How to Use the Tile Parameter

Add `--tile` to the end of your prompt.



------

## Chapter 42: Tile Examples

How to Use the Tile Parameter

### Version

Version

Midjourney regularly introduces new model versions to improve coherency, efficiency, quality, and style. You can switch model versions using the --version or --v parameter or using the /settings command and selecting your preferred model version. Different models excel at producing different types of images.

`--version` accepts the values 1, 2, 3, 4, 5, 5.0, 5.1, 5.2, 6, and 6.1.

`--version` can be abbreviated `--v`.

`--v 6.1` is the newest and current default model.

### Model Version 6.1

Version 6.1 was released on July 30, 2024 as the new default model. It produces more coherent images with more precise details and textures, and generates images approximately 25% faster than Version 6.

Prompt: vibrant California poppies --v 6.1

Prompt: high contrast surreal collage --v 6.1

### Model Version 6

Midjourney Model Version 6 has enhanced prompt accuracy for longer inputs, improved coherence and knowledge, and advanced image prompting and remixing capabilities.

Midjourney Model Version 6 was released on December 20, 2023, and was the default model from February 14 to July 30, 2024.

Prompt: vibrant California poppies --v 6

Prompt: high contrast surreal collage --v 6

### Niji Model 6

The Niji model is a collaboration between Midjourney and Spellbrush tuned to produce anime and illustrative styles with vastly more knowledge of anime, anime styles, and anime aesthetics. It's excellent at dynamic and action shots and character-focused compositions.

To use this model, add the `--niji 6` parameter to the end of a prompt, or use the `/settings` command and select `üåà Niji version 6`

Prompt: vibrant California poppies --niji 6

Prompt: high contrast surreal collage --niji 6

Niji 6 vs. Midjourney Version 6

`--v 6`

`vibrant California poppies --v 6`

`--niji 6`

`vibrant California poppies --niji 6`

`--v 6`

`fruit salad tree --v 6`

`--niji 6`

`fruit salad tree --v 6 --style raw`

### How to Switch Models

Use the Version Parameter

Use the `--version` or `--v` parameter to change model versions. For example, `--v 5.2` to use Version 5.2, or `--niji 6` to user Niji Version 6.

Use the Discord Settings Command

Type `/settings` and select your preferred version from the drop-down list.

`6Ô∏è‚É£ MJ Version 6.1` `6Ô∏è‚É£ MJ Version 6` `üåà Niji Version 6`

Looking for more information about the older models of Midjourney? Check out the Legacy Model Versions page.

Website Settings

You can set a default Version using the Settings button in the imagine bar:

Select your preferred version from the drop-down menu. Your images will be generated with that version unless you specify a different value using the `--version` or `--v` parameter in an individual prompt.



------

## Chapter 43: Model Version 6.1

Model Version 6

Niji Model 6

Niji 6 vs. Midjourney Version 6

How to Switch Models

Use the Version Parameter

Use the Discord Settings Command

Website Settings

### Video

Video

Use the `--video` parameter to create a short movie of your initial image grid being generated. React to the finished job with the envelope ✉️ emoji to have the Midjourney Bot send a link to the video to your Direct Messages.

`--video` only works on image grids, not upscales.

`--video` only works on images generated in Discord.

`--video` works with Model Versions `5.2` `6` `niji 5` and `niji 6`.

`--video` works with Legacy Model Versions `1` `2` `3` `5.0` `5.1` `test` and `testp`.  
Generated videos are deleted 30 days after creation.

### Video Examples

vibrant California Poppies

a botanical sketch of a fern fronds

### How to Get a Video Link

Prompt example: `/imagine prompt` `Vibrant California Poppies --video`

`1` Add `--video` to the end of your prompt.

`2` Once the Job has finished, click Add Reaction

`3` Select the ✉️ Envelope emoji.

`4` The Midjourney bot will send a link to the video to your Direct Messages.

`5` Click the link to view your video within a browser. Right-click or Long Press to download the video.

### How to Use the Video Parameter

Add `--video` to the end of your prompt.

Subscribers can work one-on-one with the Midjourney Bot in Discord's Direct Messages instead of a public channel. Images made within your direct messages are still subject to content and moderation rules and will be visible on your Midjourney website gallery.



------

## Chapter 44: Video Examples

How to Get a Video Link

How to Use the Video Parameter

### Weird

Weird

Explore unconventional aesthetics with the experimental `--weird` or `--w` parameter. This parameter introduces quirky and offbeat qualities to your generated images, resulting in unique and unexpected outcomes.

`--weird` accepts values: 0â€`3000.  
The default --weird value is 0.  
--weird is a highly experimental feature. What's weird may change over time  
--weird is compatible with Midjourney Model Versions 5, 5.1, 5.2, 6, niji 5 and niji 6  
--weird is not fully compatible with seeds

### The Influence of Weird on Jobs

The optimal `--weird` value is dependent on the prompt and requires experimentation. Try starting with smaller values, such as 250 or 500, and then go up/down from there. If you want a generation to be conventionally attractive and weird, try mixing higher `--stylize` values with `--weird`. Try starting with similar values for both. Example `/imagine prompt` `cyanotype cat --stylize 250 --weird 250`.

prompt example: `/imagine prompt` `cyanotype cat --weird 250`

`--weird 0`

`--weird 250`

`--weird 500`

`--weird 1000`

prompt example: `/imagine prompt` `lithograph potato --weird 250`

`--weird 0`

`--weird 250`

`--weird 500`

`--weird 1000`

prompt example: `/imagine prompt` `clockwork chicken --weird 250`

`--weird 0`

`--weird 250`

`--weird 500`

`--weird 1000`

### What's the difference between `--weird`, `--chaos`, and `--stylize`?

`--chaos` controls how diverse the initial grid images are from each other.  
`--stylize` controls how strongly Midjourney's default aesthetic is applied.  
`--weird` controls how unusual an image is compared to previous Midjourney images.

### How to Use Weird

Use the Weird Parameter

Add `--weird <value>` or `--w <value>` to the end of your prompt on Discord or in the imagine bar on the website:

Website Settings

You can set a default Weirdness using the Settings button in the imagine bar:

Adjust the slider left for lower values and right for higher values.

The value you set here will apply to all your prompts unless you specify a different value using the `--weird` or `--w` parameter in an individual prompt.



------

## Chapter 45: Text Generation

Text Generation

With Midjourney Version 6, you can use double quotation marks (`"`) around words or phrases in your prompts to specify text you want to appear in your images.

When using Midjourney Version 6, you can use "quotation marks" to indicate parts of your prompt you want to appear in your image as text: `a cyberpunk cat with a neon sign that says "Midjourney"`.

Single quote marks/apostrophes won't work--Midjourney only recognizes "words and phrases in double quotations" as text that should appear in the resulting image.

Text generation is supported for standard Latin alphabet (English) characters. Shorter words and phrases are more likely to be generated accurately.

If you're having trouble generating the exact word or phrase in your prompt, try using `--style raw` or lower Stylize values, or try using Vary Region to correct small issues.

### Examples

`/imagine prompt: a cyberpunk cat with a neon sign that says "Midjourney"`

`/imagine prompt: a pastel watercolor landscape with "/imagine" written in the clouds`

`/imagine prompt: a cartoon drawing of a manual with the words "read the docs" in big text on the pages`



------

## Chapter 46: Examples

### Image Prompts

Image Prompts

You can use images as part of a prompt to influence a Job's composition, style, and colors. Images prompts can be used alone or with text prompts—experiment with combining images with different styles for the most exciting results.

To add images to a prompt, type or paste the web address where the image is stored online. The address must end in an extension like .png, .gif, or .jpg. After adding image addresses, add any additional text and parameters to complete the prompt.

Prompts must have multiple image prompts or a single image prompt and a text prompt to work.

An image URL must be a direct link to an online image.

Your file should end in .png, .gif, .webp, .jpg, or .jpeg.

In most browsers, right-click or long-press an image and select Copy Image Address to get the URL.

The `/blend` command is a simplified image prompting process optimized for mobile users.

You can also use image URLs as Style References or Character References.

Privacy Notes

Upload images in your direct messages with the Midjourney Bot to prevent other server users from seeing an image.

Image prompts and references are visible on the Midjourney website unless you're generating in Stealth Mode.

### How to Use an Image in Your Prompt

1\. Upload an image to Discord

Follow these instructions to upload your image to Discord.

2\. Copy your image's URL

*Discord Desktop App: Right-click on the image and select Copy Link (NOT "Copy Message Link").

Discord Web App: Click to expand the image, then right-click and choose "Copy image address."

Discord Mobile App: Tap and hold on the image, then select "Copy Media Link."

If none of these methods work, you can click to expand the image, and at the bottom, select "Open in Browser" so you can copy and paste the image's URL.

To incorporate an image into your prompt, you need a direct image link that ends with .png, .gif, .webp, .jpg, or .jpeg. If the image is on your computer or phone, you can send it as a message to the Midjourney Bot first to generate a link.

How To Upload Your Image

Add an Image URL to Your Prompt

To add an image to a prompt, begin typing `/imagine` as usual. After the prompt box appears, drag the image file into the prompt box to add the image's URL, or right-click and paste the link within the prompt box.

### Examples

Starting Images

Greecian style statue

Vintage Flower Illustration

Ernst Haeckel's Jellyfish

Ernst Haeckel's Lichen

Hokusai's The Great Wave

Midjourney Model Version 5

Statue + Flowers

\+ 

Statue + Jellyfish

\+ 

Statue + Lichen

\+ 

Statue + Wave

\+ 

Statue + Lichen + Flowers

\+  \+ 

Aspect Ratio Tip

Crop images to the same aspect ratio as your final image for the best results.

### Image Weight Parameter

Use the image weight parameter `--iw` to adjust the importance of the image vs. text portion of a prompt. The default value is used when no `--iw` is specified. Higher `--iw` values mean the image prompt will have more impact on the finished job.

See the Multi Prompts page for more information about the relative importance between parts of a prompt.

Different Midjourney Version Models have different image weight ranges.

Version 6Version 5Version 4niji 6niji 5  
Image Weight Default11NA11  
Image Weight Range0–30–2NA0–30–2  
  
prompt example: `/imagine prompt` `flowers.jpg birthday cake --iw .5`

Image Prompt

--iw .25

--iw .5

--iw .75

--iw 1

--iw 1.25

--iw 1.5

--iw 1.75

--iw 2

--iw 3

### Technical Details

Prompts that only use images and no text are not compatible with the --stylize, or --weird parameters.



------

## Chapter 47: How to Use an Image in Your Prompt

1\. Upload an image to Discord

2\. Copy your image's URL

How To Upload Your Image

Add an Image URL to Your Prompt

Examples

Starting Images

Midjourney Model Version 5

Statue + Flowers

Statue + Jellyfish

Statue + Lichen

Statue + Wave

Statue + Lichen + Flowers

Image Weight Parameter

Technical Details

### Multi Prompts

Multi Prompts

The Midjourney Bot can blend multiple concepts using :: as a separator. Using a multi-prompt allows you to assign relative importance to the concept in the prompt, helping you control how they are blended together.

Multi-Prompt Basics

Adding a double colon `::` to a prompt indicates to the Midjourney Bot that it should consider each part of the prompt individually. For the prompt `space ship` both words are considered together, and the Midjourney Bot produces images of sci-fi spaceships. If the prompt is separated into two parts, `space:: ship`, both concepts are considered separately, then blended together creating a sailing ship traveling through space.  
  
There is no space between the double colons `::`  
Multi-prompts work with Model Versions `1`, `2`, `3`, `4`, `'5`, `niji`, and `niji 5`  
Any parameters are still added to the very end of the prompt.

`space ship`

space ship is considered as a single thought.

`space:: ship`

space and ship are considered separate thoughts

`cheese cake painting`

cheese cake painting is considered together, producing a painted image of a cheesecake.

`cheese:: cake painting`

cheese is considered separately from cake painting, producing images of painted cakes made of cheeses.

`cheese:: cake:: painting`

cheese, cake, and painting are considered separately, producing tiered cakes, made of cheeses with common classical painting compositions and elements.

Prompt Weights

When a double colon `::` is used to separate a prompt into different parts, you can add a number immediately after the double colon to assign the relative importance to that part of the prompt.

In the example below, the prompt `space:: ship` produced a sailing ship traveling through space. Changing the prompt to `space::2 ship` makes the word space twice as important as the word ship, producing images of space that have ships as a supporting element.

[Model Versions] `1`, `2`, `3` only accept whole numbers as weights  
[Model Versions] `4`, `niji 4`, `niji 5`, `5`, `5.1`, and `5.2` and can accept decimal places for weights  
Non-specified weights default to 1.

`space:: ship`

space and ship are considered as separate thoughts

`space::2 ship`

space is twice as important as ship

Weights are normalized:  
`space:: ship` is the same as `space::1 ship`, `space:: ship::1`, `space::2 ship::2`, `space::100 ship::100`, etc.  
`cheese::2 cake` is the same as `cheese::4 cake::2`, `cheese::100 cake::50` etc.  
`cheese:: cake:: painting` is the same as `cheese::1 cake::1 painting::1`, `cheese::1 cake:: painting::`, `cheese::2 cake::2 painting::2` etc.

### Negative Prompt Weights

Negative weights can be added to parts of a multi-prompt to help remove unwanted elements.  
The sum of all weights must be a positive number.

`still life gouache painting`

a range of objects appear in the still life

`still life gouache painting:: fruit::-.5`

The still life has fewer fruits

The `--no` Parameter

The `--no` parameter is the same as weighing part of a multi prompt to "-.5" `vibrant tulip fields:: red::-.5` is the same as `vibrant tulip fields --no red`.



------

## Chapter 48: Multi-Prompt Basics

space ship

space:: ship

Prompt Weights

space:: ship

space::2 ship

Negative Prompt Weights

The --no Parameter

### Remix

Remix

Enable Remix Mode to edit your prompt text and parameters after generating an image. It can help you change the setting or lighting of an image, evolve a subject, or acheive tricky compositions.

Turn Remix Mode on by using the `/prefer remix` command or by using `/settings` command and clicking the `üéõÔ∏è Remix Mode` button.

Once enabled, Remix Mode allows you to edit your prompt when you make a variation (including `Vary (Region)`), Reroll üîÑ, or Pan an existing image.

You can edit image references, model version, parameters, and weights in addition to prompt text when using Remix Mode, but the resulting combination of prompt elements must still work.

If you don't change anything about the prompt in the Remix window, Midjourney will generate a normal variation.

Remixing takes into account your variation mode settings.

While `Remix Mode` is enabled, `V` buttons turn green instead of blue when clicked.

### Using Remix

Turn Remix Mode on by using the `/prefer remix` command or by using `/settings` command and clicking the `üéõÔ∏è Remix Mode` button. Once Remix mode is active:

Step 1

`line-art stack of pumpkins`

Click a `ü™Ñ Vary` or `V` button.

Select an image grid or upscaled image to Remix.

Step 2

`Remix`

Change your prompt.

Modify or enter a new prompt in the pop-up.

Results

`pile of cartoon owls`

The Midjourney Bot generates an image using the new prompt with influence from the original image.

Starting Image

line-art stack of pumpkins

Model Change

line-art stack of pumpkins --test

Subject Change

balloon-animal shaped stack of pumpkins"

Medium Change

vibrant illustrated stack of fruit

### Changing Parameters with Remix

You can add or remove Parameters while using Remix mode, but you must use valid parameter combinations. Changing `/imagine prompt` `illustrated stack of pumpkins --version 3 --stylize 10000` to `illustrated stack of pumpkins --version 4 --stylize 10000` will return an error because Midjourney Model Version 4 is incompatible with Stylize values over 1000.

Only parameters that normally influence variations will work while using Remix:

Affects Initial   
GenerationAffects Variations   
and Remix  
Aspect Ratio*‚úì‚úì  
Chaos‚úì  
Image Weight‚úì  
No‚úì‚úì  
Quality‚úì  
Seed‚úì  
Same Seed‚úì  
Stop‚úì‚úì  
Stylize‚úì  
Tile‚úì‚úì  
Video‚úì‚úì  
  
Changing aspect ratios with Remix will stretch an image. It will not extend the canvas, add missing details, or fix a bad crop. To adjust aspect ratios or fix cropping issues, try Zoom or Pan instead.

### Variation Modes and Remix

In Midjourney Versions 5 and 6 and Niji Versions 5 and 6, you can choose between `üé® High Variation Mode` (the default) and `üé® Low Variation Mode`. This setting applies to Remixing variations as well, which means you'll see stronger changes with High Variation Mode and subtler changes with Low Variation Mode. You may have trouble changing the subject or composition of your image with Remix if you have Low Variation Mode enabled, for example, but it can be useful for changing details.

Examples

Starting Image

a horse

Low Variation Mode

a unicorn - Remix (Subtle)

High Variation Mode

a unicorn - Remix (Strong)



------

## Chapter 49: Using Remix

Step 1

Step 2

Results

Starting Image

Model Change

Subject Change

Medium Change

Changing Parameters with Remix

Variation Modes and Remix

Examples

Starting Image

Low Variation Mode

High Variation Mode

### Style Tuner

Style Tuner

Personalize the appearance of your Midjourney images using the Style Tuner. Use the /tune command to generate a range of sample images showing different visual styles based on your prompt. Choose your favorite images, and you'll receive a unique code you can use to customize the look of future Jobs.

Share your Style Tuner and Codes with others to share, explore, and experiment with different aesthetics.

`/tune` and codes are only compatible with Midjourney Model Version 5.2  
`/tune` is not compatible with the current default Midjourney Model Version 6  
`/tune` is only available while in Fast Mode.  
`--style` parameters created with the Style Tuner are compatible with `--stylize` values between 20â€`1000.

### How to Use the Style Tuner

1\. Generate Your Custom Style Tuner

Create a Style Tuner page using the `/tune` command.

2\. Select Your Preferred Options

Style Directions: Choose the number of image pairs you want to see in your Style Tuner (16, 32, 64, or 128 pairs).

Default Mode: Select the style mode for your sample images (Default or Raw). If you typically do not use the --style raw parameter with your prompts, choose "default."

Use an Exisiting Style Tuner

If another user has previously generated a Style Tuner with your prompt, you will receive a link to that Tuner. Click the link to access the existing Style Tuner. Using a previously generated Style Tuner does not use your subscription's GPU minutes.

3\. Submit your Job

Click the `Submit` button.

Confirm your submission.

Your Style Tuner generates a pair of images for each Style Direction. A Style Tuner with 16 directions will generate 32 images. A Style Tuner with 128 directions will generate 256 images. Generating these images uses your subscription's Fast GPU time.

4\. Open Your Custom Style Tuner

When your Style Tuner is ready, the Midjourney Bot will send you a direct message with a link to your Tuner.

Click the link to open your Style Tuner in your web browser.

Try this Style Tuner: https://tuner.midjourney.com/ejYLCOY

5\. Select images

Your Style Tuner will show rows of image pairs, each representing a distinct visual direction for your prompt. Click on the image you prefer in each pair. If you don't feel strongly about either image, leave the empty middle box selected.

6\. Copy Your Code

The Style Tuner generates a code you can add to your prompts with the `--style <code>` Parameter. Learn more about parameters.

To copy your prompt and Parameter

Find your customized code at the bottom of the page.

Click the `Copy` button to copy your original prompt and newly generated `--style <code>` parameter.

You can share your Style Tuner page with friends and generate new codes without using any additional GPU minutes!

7\. Generate an Image

Return to Discord

Use the `/imagine` command and paste your copied prompt and `--style <code>` parameter into the `prompt` field.

Generate your image

8\. Use Additional Midjourney Tools

Take your image further by using other Midjourney tools like Upscale, Pan, Zoom-Out, Remix, or Vary-Region.

9\. Experiment and Explore

Use your style code with a new prompt:

The Style Tuner you create uses your initial prompt to create sample images and help you visualize the impact of your choices. However, the generated codes can be used with any prompt. Remember that styles and prompts always work together to generate an image, so a style code may not transfer as intended to other prompts.

Experiment: Style codes and prompts interact in complex ways. A code may have a strong effect on one prompt and a subtle effect on a similar prompt. The images you choose in your Style Tuner can combine in unexpected and creative ways. Use style codes as a tool to explore new looks and visuals.

Generate more codes: You can return to your Style Tuner page at any time to change your selections and create new codes.

Share style codes: You can share or use style codes created by friends.

Find a Style Tuner page: Find the Style Tuner page for any style code by adding it to this URL: https://tuner.midjourney.com/code/StyleCodeHere.

10\. Save and Reuse Your Codes

Use the `/settings` command and turn on `ðŸ`ŒSticky Style`. Sticky Style will save the last `--style` parameter used in your personal suffix, so you don't have to repeat the code on future prompts. Change codes by using a new `--style` or unselecting `ðŸ`ŒSticky Style`.

Use custom options to store your favorite codes.

Or, create your own Discord server to organize your images, prompts, image references, and Style Tuner codes.

### Style Tune Examples

`prompt` `vibrant california poppies`  
All images were made by style created using this Style Tuner

### Random Codes

Use the `--style random` parameter to apply a random 32 base styles Style Tuner code to your prompt. You can also use `--style random-16`, `--style random-64` or `--style random-128` to use random results from other lengths of tuners.

`--random` simulates Style Tuner code with random selections chosen for 75% of the image pairs. You can adjust this percentage by adding a number to the end of the `--random` parameter. For example, `--style random-32-15` simulates a 32-pair tuner with 15% of the image pairs selected, `--style random-128-80` simulates a 128-pair tuner with 80% of the image pairs selected.

### Combine Codes

Combine multiple codes in one parameter with a hyphen, `--style code1-code2`.  
Combine multiple codes and style raw: `--style raw-code1-code2`

### Style Tuner and --stylize

The `--stylize` parameter adjusts the influence of the --style parameter on your generated images. If you're not seeing the desired effect from your code, consider combining it with higher stylization values, like `--stylize 250`, or `--stylize 500`.

Comparison

`prompt` `vibrant California poppies --style fdeQ4zOX5jd --stylize 250`

--stylize 20

--stylize 100 (default)

--stylize 250

--stylize 750

### Style Raw

Combine your custom style code with Midjourney Style Raw by using `--style raw-<code>`.  
Example: To use Style Raw and `--style fjo5S8BgMoV` use `--style raw-fjo5S8BgMoV`.

### Style Tuner and Niji Model Version

Style Tuner codes created with the Midjourney Bot are not compatible with the Niji Model version accessed through the Midjourney Bot. To create a Style Tuner or Code for Niji Model version, join the Niji Discord community and interact with the Niji Bot in the same way you interact with the Midjourney Bot. Your Midjourney subscription gives you access to the Niji community and Bot.

### Technical Details

`/tune` is compatible with prompts that include the following:  
--aspect  
--chaos  
--tile  
multi prompts

`/tune` and style codes are not compatible with image prompts that do not include a text prompt.

If your `/tune` command does not return a clickable link, check that Embeds and Link Previews is enabled in your Discord App Settings  

### There are two modes for image generation, Fast Mode andÂ Relax Mode. Fast Mode tries to give you a GPU instantly. It's the highest-priority processing tier and uses your subscription's monthly GPU time. Relax Mode queues your generation behind others based on how much you've used the system. Relax Mode wait times are variable and usually range from 1â€`10 minutes

By default, your images will be generated using Fast mode. You can switch to RelaxÂ if you have a Standard or Pro subscription.

There are two modes for image generation, Fast Mode andÂ Relax Mode. Fast Mode tries to give you a GPU instantly. It's the highest-priority processing tier and uses your subscription's monthly GPU time. Relax Mode queues your generation behind others based on how much you've used the system. Relax Mode wait times are variable and usually range from 1â€`10 minutes.

By default, your images will be generated using Fast mode. You can switch to RelaxÂ if you have a Standard or Pro subscription.

Parameters are options added to a prompt that change how an image generates. Parameters can change an image's Aspect Ratios, switch between Midjourney Model Versions, change which Upscaler is used, and lots more.



------

## Chapter 50: How to Use the Style Tuner

1\. Generate Your Custom Style Tuner

2\. Select Your Preferred Options

3\. Submit your Job

4\. Open Your Custom Style Tuner

5\. Select images

6\. Copy Your Code

7\. Generate an Image

8\. Use Additional Midjourney Tools

9\. Experiment and Explore

10\. Save and Reuse Your Codes

Style Tune Examples

Random Codes

Combine Codes

Style Tuner and --stylize

Comparison

Style Raw

Style Tuner and Niji Model Version

Technical Details

### Pan

Pan

The Pan option allows you to expand the canvas of an image in a chosen direction without changing the content of the original image. The newly expanded canvas will be filled in using guidance from the prompt and the original image.

Pan allows you to increase the image resolution beyond the maximum 1024px x 1024px dimensions in one direction.  
Pan is compatible with Midjourney Model Version 5, 5.1, 5.2, and niji 5

Panning an Image

The Pan buttons `⬅️` `➡️` `⬆️` `⬇️` will appear after upscaling an image. When panning, only the closest 512 pixels to the side of the image, along with the prompt, are used to determine the new section.

`Prompt: A vibrant fantasy landscape`

Starting Image

Pan `⬆️`

Pan `⬇️`

Pan `⬅️`

Pan `➡️`

After panning an image once, you can only pan that image again in the same direction (horizontal/vertical). You may continue to pan in that direction as often as you like. After panning several times, the image may become too large to send on Discord. When this happens, you will be sent a link to the image instead.

Pan `⬅️` and `➡️` several times

### Pan with Remix Mode

Panning supports Remix Mode. This allows you to change your prompt when panning.

Starting Image

Starting prompt: `A vibrant fantasy landscape`

Pan `➡️` \+ `Remixed Prompt`

Pan `➡️` \+ ` Remix prompt: A vibrant fantasy city`



------

## Chapter 51: Panning an Image

Pan with Remix Mode

### Zoom Out

Zoom Out

The Zoom Out option allows you to extend the canvas of an upscaled image beyond its original boundaries without changing the content of the original image. The newly expanded canvas will be filled-in using guidance from the prompt and the original image.

`Zoom Out` does not increase the maximum 1024px x 1024 px size of an image.

### Zoom Out

`üîé Zoom Out 2X` `üîé Zoom Out 1.5X` buttons will appear after upscaling an image.

Prompt: vibrant California poppies

`Starting Image`

`Zoom Out 1.5X`

`Zoom Out 2X`

### Make Square

With `Make Square` you can adjust the aspect ratio of a non-square image to make it square. If the original aspect ratio is wide (landscape), it will be expanded vertically. If it is tall (portrait), it will be expanded horizontally. The emoji `‚ÜîÔ∏è` `‚ÜïÔ∏è` next to the `‚ÜîÔ∏è Make Square` button also indicates which way the image will be expanded. The `‚ÜîÔ∏è Make Square` button will appear underneath non-square upscaled images.

Prompt: vibrant California poppies

`Starting Image`

`‚ÜïÔ∏è Make Square`

`Starting Image`

`‚ÜîÔ∏è Make Square`

### Custom Zoom

The `üîé Custom Zoom` button lets you choose how much to zoom out on an image. `üîé Custom Zoom` button under an upscaled image will pop up a dialogue box where you enter a custom value for `--zoom`. `--zoom` accepts values between 1-2.

Change the Aspect Ratio of an Upscaled Image

You can use `--zoom 1` in this `Custom Zoom` pop-up box to change the aspect ratio, with the `--ar parameter`, without zooming out.

Change Your Prompt with Custom Zoom

`üîé Custom Zoom` allows you to change the prompt before you expand your image, giving you finer control over the finished image. For example, changing the prompt to "A framed picture on the wall" gives this result:

`Starting Image`

prompt: vibrant California poppies

`Custom Zoom + Changed Prompt`

`Zoom Out` prompt: A framed picture on the wall --zoom 2



------

## Chapter 52: Zoom Out

Make Square

Custom Zoom

Change Your Prompt with Custom Zoom

### Permutation Prompts

Permutation Prompts

Permutation Prompts allow you to quickly generate variations of a prompt with a single `/imagine` command. By including lists of options separated with commas `, ` within curly braces `{}` in your prompt, you can create multiple versions of a prompt with different combinations of those options.

Basic Subscribers can create a maximum of 4 Jobs with a single Permutation Prompt.  
Standard Subscribers can create a maximum of 10 Jobs with a single Permutation Prompt.  
Pro and Mega Subscribers can create a maximum of 40 Jobs with a single Permutation Prompt.

You can use Permutation Prompts to create combinations and permutations involving any part of a Midjourney Prompt, including text, image prompts, parameters, or prompt weights.  
Permutation prompts are only available while using Fast mode.

### Permutation Prompt Basics

Separate your list of options within curly brackets {} to quickly create and process multiple prompt variations.  
  
Prompt Example:  
`/imagine prompt` `a {red, green, yellow} bird` creates and processes three Jobs.

`/imagine prompt` `a red bird`  
`/imagine prompt` `a green bird`  
`/imagine prompt` `a yellow bird`

GPU Minutes

The Midjourney Bot processes each Permutation Prompt variation as an individual Job. Each Job consumes GPU minutes.

Permutation Prompts will show a confirmation message before they begin processing.

### Permutation Prompt Examples

Prompt Text Variations

The prompt `/imagine prompt` `a naturalist illustration of a {pineapple, blueberry, rambutan, banana} bird` will create and process four Jobs:

a naturalist illustration of a pineapple bird

a naturalist illustration of a blueberry bird

a naturalist illustration of a rambutan bird

a naturalist illustration of a banana bird

### Prompt Parameter Variations

The prompt `/imagine prompt` `a naturalist illustration of a fruit salad bird --ar {3:2, 1:1, 2:3, 1:2}` will create and process four Jobs with different aspect ratios:

a naturalist illustration of a fruit salad bird --ar 3:2

a naturalist illustration of a fruit salad bird --ar 1:1

a naturalist illustration of a fruit salad bird --ar 2:3

a naturalist illustration of a fruit salad bird --ar 1:2

The prompt `/imagine prompt` `a naturalist illustration of a fruit salad bird --{v 5, niji, test}` will create and process three Jobs using different Midjourney Model Versions:

a naturalist illustration of a fruit salad bird --v 5

a naturalist illustration of a fruit salad bird --niji

a naturalist illustration of a fruit salad bird --test

### Multiple and Nested Permutations

It is possible to use multiple sets of bracketed options in a single prompt.  
`/imagine prompt` `a {red, green} bird in the {jungle, desert}` creates and processes four Jobs.

`/imagine prompt` `a red bird in the jungle`  
`/imagine prompt` `a red bird in the desert`  
`/imagine prompt` `a green bird in the jungle`  
`/imagine prompt` `a green bird in the desert`

It is also possible to nest sets of bracketed options inside other sets of brackets within a single prompt:

Example: `/imagine prompt` `A {sculpture, painting} of a {seagull {on a pier, on a beach}, poodle {on a sofa, in a truck}}.`

`/imagine prompt` `A sculpture of a seagull on a pier.`  
`/imagine prompt` `A sculpture of a seagull on a beach.`  
`/imagine prompt` `A sculpture of a poodle on a sofa.`  
`/imagine prompt` `A sculpture of a poodle in a truck.`  
`/imagine prompt` `A painting of a seagull on a pier.`  
`/imagine prompt` `A painting of a seagull on a beach.`  
`/imagine prompt` `A painting of a poodle on a sofa.`  
`/imagine prompt` `A painting of a poodle in a truck.`  
  

### Escape Character

If you want to include a `, ` within the curly brackets that does not act as a separator place a backslash `\` directly before it.

`imagine prompt` `{red, pastel, yellow} bird` produces three Jobs  
`/imagine prompt` `a red bird`  
`/imagine prompt` `a pastel bird`  
`/imagine prompt` `a yellow bird`

`imagine prompt` `{red, pastel \, yellow} bird` produces two Jobs  
`/imagine prompt` `a red bird`  
`/imagine prompt` `a pastel, yellow bird`

There are two modes for image generation, Fast Mode and Relax Mode. Fast Mode tries to give you a GPU instantly. It's the highest-priority processing tier and uses your subscription's monthly GPU time. Relax Mode queues your generation behind others based on how much you've used the system. Relax Mode wait times are variable and usually range from 1–10 minutes.

By default, your images will be generated using Fast mode. You can switch to Relax if you have a Standard or Pro subscription.

A Job is any action that uses the Midjourney Bot. Jobs include using `/imagine` to create an initial image grid, upscaling images, and creating variations of images.

The Midjourney Bot processes jobs on high-end GPUs. Each minute that it takes to complete a job is a GPU minute. You have a limited amount of GPU minutes when in Fast Mode. Because image generations may be processed on multiple GPUs simultaneously, GPU minutes are not directly connected to the time you wait for an image to generate.



------

## Chapter 53: Permutation Prompt Basics

Permutation Prompt Examples

Prompt Text Variations

Prompt Parameter Variations

Multiple and Nested Permutations

Escape Character

### Remaster

Remaster

Remaster

The Remaster feature is available for upscaled images generated using earlier Midjourney Model Versions. It creates a new grid of images using the latest Midjourney Model, combining the original image's composition with the coherency of the newer Midjourney Model Version v5.2.

Remaster any previously upscaled job by clicking the `ðŸ†• Remaster` button beneath the original upscale.

To Remaster very old jobs, use the `/show` command to refresh that job in Discord.

prompt example: `/imagine prompt` `Byzantine sandcastle cathedral --v 2`

Original Model Version 2 Image

Remastered with Model Version 5.2



------

## Chapter 54: Remaster

### Model Version 5

Model Version 5

Midjourney regularly introduces new model versions to improve coherency, efficiency, quality, and style. You can switch model versions by using the /settings command and selecting your preferred model version. Different models excel at producing different types of images.

Read about the latest Midjourney Models here.

### Default Parameter Values

Model Version 5, 5.1, and 5.2

Aspect RatioChaosQualitySeedStopStylize  
Default Value   
1:101Random100100  
Range   
any0‚Äì100.25 .5, or 1whole numbers 0‚Äì429496729510‚Äì1000‚Äì1000  
  
Aspect ratios greater than 2:1 are experimental and may produce unpredictable results.

### Model Version 5.2 (Legacy)

The Midjourney V5.2 model was released in June 2023. To use this model, add the `--v 5.2` parameter to the end of a prompt, or use the `/settings` command and select `5Ô∏è‚É£ MJ Version 5.2`

Default Model 06/22/23‚Äì02/14/2024

This model produces more detailed, sharper results with better colors, contrast, and compositions. It also has a slightly better understanding of prompts than earlier models and is more responsive to the full range of the `--stylize` parameter.

Prompt: vibrant California poppies --v 5.2

Prompt: high contrast surreal collage --v 5.2

Model Version 5.2 + Style Raw Parameter

Midjourney Model Versions 5.1 and 5.2 can be fine-tuned with the `--style raw` parameter to reduce the Midjourney default aesthetic.

Read more about the Midjourney `--style` parameter.

`default --v 5.2`

`vibrant California poppies`

`--v 5.2 --style raw`

`vibrant California poppies --style raw`

`default --v 5.2`

`high contrast surreal collage`

`--v 5.2 --style raw`

`high contrast surreal collage --style raw`

### Model Version 5.1 (Legacy)

The Midjourney V5.1 was released on May 4th, 2023. To use this model, add the `--v 5.1` parameter to the end of a prompt, or use the `/settings` command and select `5Ô∏è‚É£ MJ Version 5.1`

Default Model 05/03/23‚Äì06/22/23

This model has a stronger default aesthetic than earlier versions, making it easier to use with simple text prompts. It also has high Coherency, excels at accurately interpreting natural language prompts, produces fewer unwanted artifacts and borders, has increased image sharpness, and supports advanced features like repeating patterns with `--tile`.

Prompt: vibrant California poppies --v 5.1

Prompt: high contrast surreal collage --v 5.1

### Model Version 5.0 (Legacy)

The Midjourney V5.0 model produces more photographic generations than the V5.1 model. This model produces images that closely match the prompt but may require longer prompts to achieve your desired aesthetic.

Default Model 03/30/23‚Äì05/03/23

To use this model, add the `--v 5` parameter to the end of a prompt, or use the `/settings` command and select `5Ô∏è‚É£ MJ Version 5`  
  
Prompt: vibrant California poppies --v 5

Prompt: high contrast surreal collage --v 5

### Niji Model 5 (Legacy)

The Niji model is a collaboration between Midjourney and Spellbrush tuned to produce anime and illustrative styles with vastly more knowledge of anime, anime styles, and anime aesthetics. It's excellent at dynamic and action shots and character-focused compositions.

To use this model, add the `--niji 5` parameter to the end of a prompt, or use the `/settings` command and select `üçè Niji version 5`

This model is sensitive to the `--stylize` parameter. Experiment with different stylization ranges to fine-tune your images.

Niji 5 Styles

Niji Model Version 5 can also be fine-tuned with `--style` parameters to achieve unique looks. Try `--style cute`, `--style scenic`, `--style original` (uses the original Niji Model Version 5, which was the default before May 26th, 2023), or `--style expressive`.

Niji Style Parameters  
`--style cute` creates charming and adorable characters, props, and settings.  
`--style expressive` has a more sophisticated illustrated feeling.  
`--style original` uses the original Niji Model Version 5, which was the default before May 26th, 2023.  
`--style scenic` makes beautiful backgrounds and cinematic character moments in the context of their fantastical surroundings.

`default --niji 5`

birds perching on a twig --niji 5

`--style original`

birds perching on a twig --niji 5 --style original

`--style cute`

birds perching on a twig --niji 5 --style cute

`--style expressive`

birds perching on a twig --niji 5 --style expressive

`--style scenic`

birds perching on a twig --niji 5 --style scenic

### V5 Upscaler Tools

Midjourney Model Version 5.2 produces grids of 1024 x 1024 pixel images. Use the `U1` `U2` `U3` `U4` buttons under each image grid to separate your selected image from its grid. You can then use the `Upscale (2x)` or `Upscale (4x)` tools to increase the size of your image.

`Upscale` tools use your subscription's GPU minutes. Using `Upscale 2X` on an image takes roughly twice as long as generating an initial image grid. Using `Upscale 4X` on an image takes roughly six times as long as generating an initial image grid.

V5 `Upscale` tools are not compatible with the pan tool or the tile parameter.

Upscaler Comparison

`Upscale (2x)`

Original 1024 by 1024 pixel image

Detail from the original image

After `Upscale (2x)` to 2048 x 2048 px

### Upscaler Comparison

Prompt: `1960s pop-art acrylic of redwoods`  
Original 1024 by 1024 pixel image.

Original 1024 by 1024 pixel image

Detail from the original image

After `Upscale (4x)` to 4096 x 4096 px

### Influence of --stylize on Model Version 5

Midjourney Model Version 5 Stylize Comparison

prompt example: `/imagine prompt` `child's drawing of a cat --s 100`

`--stylize 50`

Equal to `üñåÔ∏è Style Low`

`--stylize 100` (default)

Equal to `üñåÔ∏è Style Med`

`--stylize 250`

Equal to `üñåÔ∏è Style High`

`--stylize 750`

Equal to `üñåÔ∏è Style Very High`

Niji 5 Stylize Comparison

prompt example: `/imagine prompt` `colorful risograph of a fig --niji 5 --s 100`

`--stylize 50`

`üñåÔ∏è Style Low`

`--stylize 100` (default)

`üñåÔ∏è Style Med`

`--stylize 250`

`üñåÔ∏è Style High`

`--stylize 750`

`üñåÔ∏è Style Very High`

Coherency is the strength of the connection between the text prompt and the resulting image. A high degree of coherency means that the image will be an accurate representation of the prompt text.

The Midjourney Bot processes jobs on high-end GPUs. Each minute that it takes to complete a job is a GPU minute. You have a limited amount of GPU minutes when in Fast Mode. Because image generations may be processed on multiple GPUs simultaneously, GPU minutes are not directly connected to the time you wait for an image to generate.



------

## Chapter 55: Default Parameter Values

Model Version 5.2 (Legacy)

Model Version 5.2 + Style Raw Parameter

Model Version 5.1 (Legacy)

Model Version 5.0 (Legacy)

Niji Model 5 (Legacy)

Niji 5 Styles

V5 Upscaler Tools

Upscaler Comparison

Upscaler Comparison

Influence of --stylize on Model Version 5

Midjourney Model Version 5 Stylize Comparison

Niji 5 Stylize Comparison

### Model Version 4

Model Version 4

Midjourney regularly introduces new model versions to improve coherency, efficiency, quality, and style. You can switch model versions by using the /settings command and selecting your preferred model version. Different models excel at producing different types of images.

Read about the latest Midjourney Models here

### Default Paramter Values

Model Version 4

Aspect RatioChaosQualitySeedStopStyleStylize  
Default Value   
1:101Random1004c100  
Range   
1:2‚Äì2:10‚Äì100.25 .5 or 1whole numbers 0‚Äì429496729510‚Äì1004a, 4b, or 4c0‚Äì1000  
  

### Model Version 4 (Legacy)

The Midjourney V4 model is an entirely new codebase and brand-new AI architecture designed by Midjourney and trained on the new Midjourney AI supercluster. The latest Midjourney model has more knowledge of creatures, places, objects, and more. It's much better at getting small details right and can handle complex prompts with multiple characters or objects. The Version 4 model supports advanced functionality like image prompting and multi-prompts.

This model has very high Coherency and excels with Image Prompts.

Prompt: vibrant California poppies

Prompt: high contrast surreal collage

Version 4 Styles 4a, 4b, and 4c

Midjourney Model Version 4 has three slightly different "flavors" with slight tweaks to the stylistic tuning of the model. Experiment with these versions by adding `--style 4a`, `--style 4b`, or `--style 4c` to the end of a V4 prompt.

`--v 4 --style 4c` is the current default and does not need to be added to the end of a prompt.

Note on Style 4a and 4b

`--style 4a` and `--style 4b` only support 1:1, 2:3, and 3:2 aspect ratios.  
`--style 4c` support aspect ratios up to 1:2 or 2:1.

`--style 4a`

vibrant California poppies --style 4a

`--style 4b`

vibrant California poppies --style 4b

`--style 4c`

vibrant California poppies --style 4c

`--style 4a`

school of fish --style 4a

`--style 4b`

school of fish --style 4b

`--style 4c`

school of fish --style 4c

### Niji Model 4 (Legacy)

The `niji 4` model is a collaboration between Midjourney and Spellbrush tuned to produce anime and illustrative styles. The `--niji 4` model has vastly more knowledge of anime, anime styles, and anime aesthetics. It's excellent at dynamic and action shots and character-focused compositions in general.

prompt example: `/imagine prompt` `vibrant California poppies --niji 4`

`--v 4`

California poppies --v 4

`--niji 4`

California poppies --niji 4

`--v 4`

birds sitting on a twig --v 4

`--niji 4`

birds sitting on a twig --niji 4

### V4 Upscaler Tools

Earlier Midjourney model versions start by generating a grid of low-resolution image options for each Job. You can use a Midjourney upscaler on any of these images to increase the size and add additional details. There are multiple upscale models available for upscaling an image. Using an upscaler uses your subscription's GPU minutes.

The `U1` `U2` `U3` `U4` buttons under each image grid are used to upscale the selected image.

Read more about current upscaling options

Midjourney Dimensions and Sizes

All sizes are for square 1:1 aspect ratios.

Model VersionStarting Grid SizeV4 Default UpscalerDetail UpscaleLight UpscaleBeta Upscale  
Version 4512 x 5121024 x 10241024 x 10241024 x 10242048 x 2048  
niji 4512 x 5121024 x 10241024 x 10241024 x 10242048 x 2048  
  
Model Version 4 Upscaler

The Midjourney Model Version 4 upscaler increases image size while smoothing or refining details. Some small elements may change between the initial grid image and the finished upscale.

prompt: `adorable rubber duck medieval knight`

prompt: `sand cathedral`

### Influence of Stylize on Model V4

prompt example: `/imagine prompt` `illustrated figs --v 4 --s 100`

`--stylize 50`

`üñåÔ∏è Style Low`

`--stylize 100` (default)

`üñåÔ∏è Style Med`

`--stylize 250`

`üñåÔ∏è Style High`

`--stylize 750`

`üñåÔ∏è Style Very High`

### Coherency is the strength of the connection between the text prompt and the resulting image. A high degree of coherency means that the image will be an accurate representation of the prompt text

The Midjourney Bot processes jobs on high-end GPUs. Each minute that it takes to complete a job is a GPU minute. You have a limited amount of GPU minutes when in Fast Mode. Because image generations may be processed on multiple GPUs simultaneously, GPU minutes are not directly connected to the time you wait for an image to generate.



------

## Chapter 56: Default Paramter Values

Model Version 4 (Legacy)

Version 4 Styles 4a, 4b, and 4c

Niji Model 4 (Legacy)

V4 Upscaler Tools

Midjourney Dimensions and Sizes

Model Version 4 Upscaler

Influence of Stylize on Model V4

### Early Model Versions

Early Model Versions

Midjourney regularly introduces new model versions to improve coherency, efficiency, quality, and style. You can switch model versions by using the /settings command and selecting your preferred model version. Different models excel at producing different types of images.

Read about the latest Midjourney Models here

### Model Version 1, 2, and 3 (Legacy)

You can access earlier midjourney models by using the `--version` or `--v` parameter or by using the `/settings` command and selecting a model version. Different models excel at different types of images.

prompt example: `/imagine prompt` `vibrant California poppies --v 1`

`--version 3`

default model: 07/22–11/22

highly creative compositions

moderate coherency

`--version 2`

default model: 04/22–07/22

creative, colorful, and painterly

low coherency

`--version 1`

default model: 02/22–04/22

very abstract and painterly

low coherency

`--hd` (high definition)

early alternative model

busy detailed and abstract

low coherency

### Niji Model 4 (Legacy)

The `niji 4` model is a collaboration between Midjourney and Spellbrush tuned to produce anime and illustrative styles. The `--niji 4` model has vastly more knowledge of anime, anime styles, and anime aesthetics. It's excellent at dynamic and action shots and character-focused compositions in general.

prompt example: `/imagine prompt` `vibrant California poppies --niji 4`

`--v 4`

California poppies --v 4

`--niji 4`

California poppies --niji 4

`--v 4`

birds sitting on a twig --v 4

`--niji 4`

birds sitting on a twig --niji 4

### Test Models (Legacy)

Occasionally new models are released temporarily for community testing and feedback. There are currently two available test models: `--test` and `--testp`, which can be combined with the `--creative` parameter for more varied compositions.

prompt example: `/imagine prompt` `vibrant California poppies --testp --creative`

`--test`

A general-purpose artistic model with good coherency 

`--test` \+ `--creative`

`--testp`

A photo-realism model with good coherency

`--testp` \+ `--creative`

Notes on current test models `--test` and `--testp`

Test models only support `--stylize` values between 1250–5000.  
Test models do not support multi-prompts or image-prompts  
Test models have a maximum aspect ratio of 3:2 or 2:3.  
Test models only generate two initial grid images when the aspect ratio is 1:1.  
Test models only generate one initial grid image when the aspect ratio is not 1:1.  
Words near the front of the prompt may matter more than words near the back.

### Early Model Upscaler Tools

Earlier Midjourney model versions start by generating a grid of low-resolution image options for each Job. You can use a Midjourney upscaler on any of these images to increase the size and add additional details. There are multiple upscale models available for upscaling an image. Using an upscaler uses your subscription's GPU minutes.

The `U1` `U2` `U3` `U4` buttons under each image grid are used to upscale the selected image.

Read more about current upscaling options

Midjourney Dimensions and Sizes

All sizes are for square 1:1 aspect ratios.

Model VersionStarting Grid SizeV4 Default UpscalerDetail UpscaleLight UpscaleBeta UpscaleMax Upscale**  
v1–v3256 x 256-1024 x 1024*1024 x 10241024 x 10241664 x 1664  
niji512 x 5121024 x 10241024 x 10241024 x 10242048 x 2048-  
test / testp512 x 512---2048 x 2048-  
hd512 x 512-1536 x 1536*1536 x 15362048 x 2048-  
  
`*` = the default upscaler for each Midjourney Version Model.  
`**` Max Upscale is an older resource-intensive upscaler and is only available when users are in Fast Mode.

Light Upscaler

The Light Upscaler creates a 1024px x 1024px image and adds a moderate amount of details and textures. The Light Upscaler is useful for faces and smooth surfaces when using older Midjourney Model Versions.

Use the `--uplight` parameter to change the behavior of the `U1` `U2` `U3` `U4` upscale buttons to use the Light Upscaler.

prompt: `adorable rubber duck medieval knight`

prompt: `sand cathedral`

Detailed Upscaler

The Detail Upscaler creates a 1024px x 1024px image and adds many additional fine details to the image.

Images that have been upscaled with the detailed upscaler can be upscaled again using the `Upscale to Max` button for a final resolution of 1664px x 1664px. `Upscale to Max` is only available when in Fast mode.

The Detailed upscaler was the default for Midjourney Model Versions `V1`, `V2`, `V3`, and `hd`

prompt: `adorable rubber duck medieval knight`

prompt: `sand cathedral`

Beta Upscaler

The Beta Upscaler creates a 2048px x 2048px image without adding many additional details. The Beta Uspcaler is useful for faces and smooth surfaces.

Use the `--upbeta` parameter to change the behavior of the `U1` `U2` `U3` `U4` upscale buttons to use the Beta Upscaler.

prompt: `adorable rubber duck medieval knight`

prompt: `sand cathedral`

The Midjourney Bot processes jobs on high-end GPUs. Each minute that it takes to complete a job is a GPU minute. You have a limited amount of GPU minutes when in Fast Mode. Because image generations may be processed on multiple GPUs simultaneously, GPU minutes are not directly connected to the time you wait for an image to generate.

There are two modes for image generation, Fast Mode and Relax Mode. Fast Mode tries to give you a GPU instantly. It's the highest-priority processing tier and uses your subscription's monthly GPU time. Relax Mode queues your generation behind others based on how much you've used the system. Relax Mode wait times are variable and usually range from 1–10 minutes.

By default, your images will be generated using Fast mode. You can switch to Relax if you have a Standard or Pro subscription.



------

## Chapter 57: Model Version 1, 2, and 3 (Legacy)

Niji Model 4 (Legacy)

Test Models (Legacy)

Early Model Upscaler Tools

Midjourney Dimensions and Sizes

Light Upscaler

Detailed Upscaler

Beta Upscaler

### Legacy Model Version Parameters

Legacy Model Version Parameters

Parameters are options added to a prompt that change how an image generates. Parameters can change an image's Aspect Ratios, switch between Midjourney Model Versions, change which Upscaler is used, and lots more.

The parameters on this page only work with legacy Midjourney Model Versions. For information on parameters that work with the latests Midjourney Model Versions read more here.

### Legacy Model Version Parameters

Midjourney routinely releases new model versions to improve efficiency, coherency, and quality. Different models excel at different types of images.

Niji

`--niji 4` and `niji 5` Use an alternative model focused on anime style images.

High Definition

`--hd` Use an early alternative Model that produces larger, less consistent images. This algorithm may be suitable for abstract and landscape images.

Test

`--test` Use the Midjourney special test model.

Testp

`--testp` Use the Midjourney special photography-focused test model.

Version

`--version <1, 2, 3, 4, or 5>` or `--v <1, 2, 3, 4, or 5>` Use a different version of the Midjourney algorithm. The current algorithm is the default setting.

Legacy Upscaler Parameters

Midjourney starts by generating a grid of low-resolution image options for each Job. You can use a Midjourney upscaler on any grid image to increase the size and add additional details. There are multiple upscale models available for upscaling an image.

Uplight

`--uplight` Use an alternative "light" upscaler when selecting the U buttons. The results are closer to the original grid image. The upscaled image is less detailed and smoother.

Upbeta

`--upbeta` Use an alternative beta upscaler when selecting the U buttons. The results are closer to the original grid image. The upscaled image has significantly fewer added details.

Legacy Parameters

These parameters only work with specific earlier Midjourney Models.

Creative

`--creative` Modify the `test` and `testp` models to be more varied and creative.

Sameseed

`--sameseed` Seed values create a single large random noise field applied across all images in the initial grid. When --sameseed is specified, all images in the initial grid use the same starting noise and will produce very similar generated images.

### Compatibility

Legacy Model Version & Parameter Compatability

Affects initial generationAffects variations + remixVer. 5Ver. 4Ver. 3Test /  
TestpNiji 4Niji 5  
Max Aspect Ratio✓✓any1:2 or 2:15:2 or 2:53:2 or 2:31:2 or 2:1any  
Chaos✓✓✓✓✓✓✓  
Image Weight✓.5–2   
default=1.5–2   
default=1any   
default=.25.5–2   
default=1  
No✓✓✓✓✓✓✓✓  
Quality✓.25–1.25–1.25–2.25–2.25–2  
Repeat✓✓✓✓✓✓✓  
Seed✓✓✓✓✓✓✓  
Sameseed✓✓  
Stop✓✓✓✓✓✓✓✓  
Styleraw4a, and 4bexpressive, and cute  
Stylize✓0–1000   
default=1000–1000   
default=100625–60000   
default=2500)1250–5000   
default=2500)0–1000   
default=100)  
Tile✓✓✓✓✓  
Video✓✓  
Weird✓✓  
Number of Grid Images--4442 (1 when aspect ratio≠1:1)44  
  

### Deprecated Parameters

--width and --w (replaced with --aspect)  
--height and --h (replaced with --aspect)  
--fast (replaced with --quality)  
--vibe (now known as V1)  
--upanime  
--hq  
--newclip  
--nostretch  
--old



------

## Chapter 58: Legacy Model Version Parameters

Niji

High Definition

Test

Testp

Version

Legacy Upscaler Parameters

Uplight

Upbeta

Legacy Parameters

Creative

Sameseed

Compatibility

Legacy Model Version & Parameter Compatability

Deprecated Parameters

### Subscription Plans

Subscription Plans

Midjourney has four subscription tiers. Pay month-to-month or for the entire year for a 20% discount. Each subscription plan includes access to the Midjourney member gallery, the official Discord, general commercial usage terms, and more.

How to Subscribe

In the Midjourney Discord server use the `/subscribe` command to generate a personal link to the subscription page.

Or, log into the Midjourney website and go to Midjourney.com/account.

Or, log into the Midjourney website and click on your name and then `Manage Subscription` from the sidebar.

Billing and Subscription Help

For billing and subscription questions, please visit help.midjourney.com.

### Plan Comparison

Basic PlanStandard PlanPro PlanMega Plan  
Monthly Subscription Cost$10$30$60$120  
Annual Subscription Cost$96   
($8 / month)$288   
($24 / month)$576   
($48 / month)$1152   
($96 / month)  
Fast GPU Time3.3 hr/month15 hr/month30 hr/month60 hr/month  
Relax GPU Time-UnlimitedUnlimitedUnlimited  
Purchase Extra  
GPU Time$4/hr$4/hr$4/hr$4/hr  
Work Solo In Your  
Direct Messages✓✓✓✓  
Stealth Mode--✓✓  
Maximum Concurrent Jobs3 Jobs  
10 Jobs waiting in queue3 Jobs  
10 Jobs waiting in queue12 Fast Jobs  
3 Relaxed Jobs   
10 Jobs in queue12 Fast Jobs  
3 Relaxed Jobs   
10 Jobs in queue  
Rate Images to Earn Free GPU Time✓✓✓✓  
Usage RightsGeneral Commercial Terms*General Commercial Terms*General Commercial Terms*General Commercial Terms*  
  
If you have subscribed at any point, you are free to use your images in just about any way you want. You must purchase the Pro or Mega plan if you are a company making more than $1, 000, 000 USD in gross revenue per year. For complete details, please see the Terms of Service

Subscribe to a Plan

Go to https://www.midjourney.com/account/ or use the `/subscribe` command to generate a link to the subscription page.

Don't Share Your Link

The generated link is unique for each account and should never be shared with others!

Payment Methods

Only payment methods supported by Stripe are currently accepted: credit or debit cards issued by services like Mastercard, VISA, or American Express. Stripe is a PCI Service Provider Level 1, the most stringent level of certification available in the payments industry.

Google Pay and Apple Pay are available in some regions.

PayPal, wire transfer, and similar methods are not supported.

### Manage Your Plan

Manage your subscription plan at https://www.midjourney.com/account/.

Automatic Renewal

Unused monthly Fast GPU time does not roll over.

Your payment method on file with our third party payment processor will be automatically charged at the end of each monthly or annual billing period.

Switch Plans

Upgrade your plan at any time. When upgrading, you may choose whether the upgrade should be effective immediately or at the end of the current billing cycle. If you choose to upgrade immediately, you will be offered a prorated price based on the usage of the plan you are upgrading from. Downgrades are always effective at the end of the current billing cycle.

Proration?

Unused Fast GPU Time is credited towards your account when you choose to upgrade immediately. If a Basic subscriber upgrades immediately without using any GPU time, they receive a $10 credit towards their new plan. If a Standard subscriber upgrades after using 50% of their Fast GPU time, they receive a $15 credit towards their new plan.

Cancellation

Go to https://www.midjourney.com/account/ to cancel a subscription at any time. Cancellations are effective at the end of the current billing cycle. Subscription benefits like access to the community gallery and the bulk download tool are available until the end of the current billing cycle.

Your generated images and Midjourney.com/account page are not deleted if you cancel your subscription. You can resubscribe to a plan at any time by visiting https://www.midjourney.com/account/.

Refunds

Refunds are available for subscribers who have lifetime usage of less than 20 GPU minutes, including time used in Relax Mode. If you are eligible for a refund, the dialog box will automatically pop up when you click to cancel your account.

### Buy More Fast Hours

Run out of Fast GPU and want to buy more before your monthly subscription renews? You can purchase additional Fast GPU hours for $4/hr. Hourly Prices are experimental and subject to change.

Purchase more Fast GPU hours on your Midjourney account page.

You must have an active subscription to use Fast GPU hours

Purchased Fast GPU hours expire after 60 days (effective October 1, 2024)

Refunds will not be issued on Fast Hours

Account Information

Use the `/info` command to view information about your account, including how much Fast time is left for the subscription period, lifetime usage stats, the number of queued or running jobs, and the subscription renewal date.



------

## Chapter 59: Plan Comparison

Subscribe to a Plan

Payment Methods

Manage Your Plan

Automatic Renewal

Switch Plans

Cancellation

Refunds

Buy More Fast Hours

Account Information

### Stealth Mode

Stealth Mode

Midjourney is an open-by-default community, and all image generations are visible at midjourney.com, including images created in private discord servers, direct messages, and on the Midjourney web app.

Subscribers to the Pro and Mega plans have access to Stealth Mode. Stealth mode prevents your images from being visible to others on the Midjourney website. Use the `/stealth` and `/public` commands toggle between Stealth and Public mode.

Stealth Mode Only Prevents Others From Viewing Your Images on Midjourney.com!  
Images generated in public channels are always visible to other users, even when using Stealth Mode. To prevent others from seeing an image you create using Stealth Mode, generate images in your Direct Messages or on a private Discord server.

If you cancel or downgrade your Midjourney subscription, previously created Stealth Mode images will remain unpublished.

### How to Switch to Stealth Mode

Your website and Discord settings are separate. This includes your preference of Stealth or Public Mode. Double-check your Discord and website settings before generating any images to be sure they're set to the mode you want to use.

In Discord

Using Commands

Use the `/stealth` as a standalone command in Discord to turn Stealth Mode on. Use `/public` to turn it off.

Switching this way will apply your choice to all your future prompts until you use a different command to change modes, choose a different mode in your settings, or use the opposite parameter in your prompt.

Using Settings

Use the `/settings` command to adjust your settings. The `üßç‚Äç‚ôÇÔ∏èPublic` button can be used to toggle between Stealth and Public mode.

When the `üßç‚Äç‚ôÇÔ∏èPublic` button is green, you are making images in Public mode.

When the `üßç‚Äç‚ôÇÔ∏èPublic` button is gray, you are making images in Stealth mode.

Using Parameters

To override your default visibility mode for a specific prompt, you can add the `--stealth` or `--public` parameter to the end.

Using `/info` to check if you are in Stealth Mode

Use the `/info` command to see information about your account. Visibility shows whether you are currently in Public or Stealth Mode.

On the Website

Website Settings

You can toggle Stealth Mode on and off in the website Settings menu:

A red `On` button means Stealth Mode is enabled. A gray `Off` button means Public Mode is enabled. Click the button to toggle between them.

Your choice will apply to all your prompts unless you use the opposite `--stealth` or `--public` parameter in an individual prompt.

Publishing and Unpublishing Existing Images

If your current subscription plan includes Stealth Mode, you can also publish or unpublish existing images on the website by using the bulk actions menu from your Archive page or the  Options menu from within an individual image view.



------

## Chapter 60: How to Switch to Stealth Mode

In Discord

Using Commands

On the Website

### Earn Free Hours

Earn Free Hours

Midjourney subscribers can earn free Fast time by ranking images and filling out surveys. A bonus Fast hour is awarded to the top 2000 ranking participants each day.

Awarded Fast hours expire 30 days from the date you earned.

You need an active subscription to earn and use free Fast hours.

### How to Rank Images

Every day, the 2000 Midjourney users who rank the most images earn a free Fast hour. There are four ways to rank images:

Curate Community Front Page

Choose the image from each set that you think most belongs on the front page of the Explore feed. These rankings don't affect your personalization.

Rank Image Aesthetics

Aesthetic rankings are based on personal preference. Choose the image you like the most based on its overall appearance, effort, colors, concept, or theme. Don't take the prompt into account.

Ranking Images Aesthetics also contributes to your Midjourney personalization.

Rank Niji Aesthetics

Niji Aesthetics ranking includes only images generated with the Niji models of Midjourney. Ranking Niji Aesthetics contributes your your Niji personalization, which applies to `--niji` images you generate with personalization turned on.

Rank Prompt Accurage

Choose the images from each pair that most accurately matches its prompt. These rankings don't affect your personalization.

### Surveys

Research surveys also appear on the Tasks tab. You'll be able to see how many Fast hours each survey awards for completion before you begin. You don't need an active Midjourney subscription to take these surveys and see your results, but you will only earn Fast time for completing them if you're an active subscriber.

### Keep Track of Your Free Hours

You can check how many earned and purchased Fast hours you have available in the Purchased & Awarded Fast Hours box on your Manage Subscription page. Hover your mouse over the  icon to see when these hours expire.

### There are two modes for image generation, Fast Mode and Relax Mode. Fast Mode tries to give you a GPU instantly. It's the highest-priority processing tier and uses your subscription's monthly GPU time. Relax Mode queues your generation behind others based on how much you've used the system. Relax Mode wait times are variable and usually range from 1–10 minutes

By default, your images will be generated using Fast mode. You can switch to Relax if you have a Standard or Pro subscription.



------

## Chapter 61: How to Rank Images

Surveys

Keep Track of Your Free Hours

### Fast, Relax, & Turbo Modes

Fast, Relax, & Turbo Modes

Midjourney uses powerful Graphics Processing Units (GPUs) to interpret and process each prompt. When you purchase a subscription to Midjourney, you are purchasing time on these GPUs.

Different subscription plans have different amounts of monthly GPU time.  
This monthly subscription GPU time is Fast Mode time. Fast Mode tries to give you access to a GPU instantly. It's the default processing tier and uses your subscription's monthly GPU time.

### How many GPU minutes do my generations cost?

The Average Job the Midjourney bot processes takes about one minute of GPU time to finish creating an image. Upscaling an image, using nonstandard aspect ratios, or older Midjourney Model Versions may take more time. Creating variations or using lower quality values will take less time.

A Job's time depends on the following factors:

\+ Lower Time++ Average Time+++ Higher Time  
Job TypeVariations`/imagine`Upscale  
Aspect Ratiodefault (square)tall or wide  
Quality Parameter`--q 0.25` or `--q 0.5`default (`--q 1`)`--q 2` (for legacy Model Versions)  
Stop Parameter`--stop 10`‚Äì`--stop 99`default (`--stop 100`)  
  
Use `/info` before and after running a process to see how many of your remaining GPU minutes the generation used.

### Fast vs. Relax Mode

Subscribers to the Standard, Pro, and Mega plans can create an unlimited number of images each month in Relax Mode. Relax Mode will not cost any GPU time, but Jobs will be placed into a queue based on how much you've used the system.

How long do I need to wait in Relax mode?

Jobs in Relax mode are placed in a queue to be processed as GPUs become available. Wait times for Relax are dynamic but generally range between 0‚Äì10 minutes per job. If you use Relax mode occasionally, you will have shorter wait times compared to subscribers that have used it more. This priority currently resets whenever you renew your monthly subscription.

Limitations

Permutation prompts, the --repeat parameter and the Legacy upscaler, Max Upscale are not available while useing Relax mode.

Run Out of Fast Time?

You can purchase more Fast Hours on your Midjourney.com/accounts page.

By default, images are generated using Fast Mode.  
Unused monthly Fast GPU time does not roll over.

### Turbo Mode

Turbo Mode is available for subscribers who want extremely quick image generation. Turbo mode uses a high-speed experimental GPU pool. Jobs run in Turbo mode generate up to four times faster but consume twice as many subscription GPU minutes as a typical Fast Mode Job.

Turbo mode is only available with Midjourney Model Versions 5, 5.1, 5.2, and 6.

If Turbo mode is selected, but the GPUs are unavailable, or it is incompatible with the selected model version, your job will run in Fast Mode instead.

Turbo Mode is an experimental feature, and availability and price may change at any time.

### How to Switch Between Modes

All users have access to Fast and Turbo Modes. Only Standard, Pro, and Mega Plan subscribers can use Relax Mode.

Your website and Discord settings are synced. This means that if you change your settings in one place, they'll automatically change in the other ‚Äî including your generation speed. Double-check your settings to make sure they're set the way you want them before you generate images!

In Discord

Using Commands

Use `/relax`, `/fast`, or `/turbo` as a standalone command in Discord to switch between image generation speeds.

Switching this way will apply your choice to all your future prompts until you use a different command to change modes, choose a different mode in your settings, or use a different mode parameter in your prompt.

Using Settings

Use the `/settings` command and choose `üê¢ Relax` `üêá Fast` or `‚ö° Turbo` from the menu.

Using the `--relax` `--fast` or `--turbo` parameters

To override your default generation speed for a specific prompt, you can add the `--fast`, `--relax`, or `--turbo` parameter at the end.

Website Settings

You can choose between Stealth and Public modes as your default "Speed" with buttons in the website Settings menu:

Your current default Speed will be highlighted in red.

The Speed you set here will apply to all your prompts unless you specify a different one using the `--relax` or `--fast` or `--turbo` parameter in an individual prompt.

A Job is any action that uses the Midjourney Bot. Jobs¬†include using `/imagine` to create an initial image grid, upscaling images, and creating variations of images.



------

## Chapter 62: How many GPU minutes do my generations cost?

Fast vs. Relax Mode

How long do I need to wait in Relax mode?

Limitations

Run Out of Fast Time?

Turbo Mode

How to Switch Between Modes

In Discord

Website Settings

### Contacting Support

Contacting Support

Most issues can be resolved without needing manual intervention. If you're still stuck, follow the instructions below to get help.

Self-Help

Use the `/ask` command to get answers to many common support questions.

### Tech Support and General Questions

We provide support directly within Discord if you have an issue with the Midjourney Bot or Midjourney.com website. You can find help in the `#support` channel, just above the newbies rooms. Volunteers and helpful community members run this channel and can't assist with billing issues.

Billing Support

Billing and Subscription Help

For billing and subscription questions, please visit help.midjourney.com.

